@@ -30,14 +30,6 @@ namespace Lum {
   */
   class LUMAPI About : public Component
   {
-  public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      Prefs(const std::wstring& name);
-      void Initialize();
-    };
-
   private:
     AppInfo info;
 
