@@ -30,14 +30,6 @@ namespace Lum {
   */
   class LUMAPI Boolean : public ImageState
   {
-  public:
-    class Prefs : public ImageState::Prefs
-    {
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   public:
     Boolean();
   };
