@@ -32,14 +32,6 @@ namespace Lum {
   */
   class LUMAPI ButtonRow : public Group
   {
-  public:
-    class Prefs : public Group::Prefs
-    {
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   private:
     size_t             buttonWidth;
     size_t             spaces;
