@@ -53,35 +53,16 @@ namespace Lum {
   */
   class LUMAPI Combo : public Control
   {
-  public:
-
-    class Prefs : public Object::Prefs
-    {
-    public:
-      OS::ImageRef readOnlyImage;
-      OS::ImageRef buttonImage;
-      OS::ImageRef divider;
-      bool         imageRight;
-      OS::FrameRef readOnlyFrame;
-      OS::FrameRef editableFrame;
-
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   private:
     class Table : public ::Lum::TableView
     {
     public:
       bool             success;
-      Model::ActionRef commit;
 
     public:
       Table();
       ~Table();
 
-      void CalcSize();
       void Resync(Base::Model* model, const Base::ResyncMsg& msg);
     };
 
@@ -98,6 +79,7 @@ namespace Lum {
     };
 
   private:
+    bool                          imageRight;
     bool                          editable;
     ::Lum::Table                  *table;
     Popup*                        popup;
