@@ -29,14 +29,6 @@ namespace Lum {
   */
   class LUMAPI DateSelect : public PopupControl
   {
-  public:
-
-    class Prefs : public PopupControl::Prefs
-    {
-    public:
-      Prefs();
-    };
-
   private:
     class Popup : public Dialog
     {
