@@ -27,8 +27,6 @@
 #include <Lum/OS/Frame.h>
 #include <Lum/OS/Window.h>
 
-#include <Lum/Prefs/Base.h>
-
 #include <Lum/Object.h>
 
 namespace Lum {
@@ -97,25 +95,7 @@ namespace Lum {
       Shortcut* GetShortcut(OS::KeyEvent* event) const;
     };
 
-  public:
-    /**
-     Special Preferences object for Dialogs.
-    */
-    class Prefs : public Lum::Prefs::Prefs
-    {
-    public:
-      OS::FrameRef mainFrame;    //! the frame to use for main dialogs
-      OS::FrameRef menuFrame;    //! the frame to use for menues
-      OS::FrameRef popupFrame;   //! the frame to use for popup and splashes
-      OS::FrameRef tooltipFrame; //! the frame to use for tooltip window
-
-    public:
-      Prefs(const std::wstring& name);
-      virtual void Initialize();
-    };
-
   private:
-    Prefs            *prefs;           //! Window preferences object
     Lum::Object      *top;             //! The top most object
 
     Lum::Object      *mouseGrab;       //! Object currently holding mouse event focus
