@@ -140,14 +140,6 @@ namespace Lum {
         bool      drawn;
       };
 
-    public:
-      class Prefs : public Scrollable::Prefs
-      {
-      public:
-        Prefs();
-        void Initialize();
-      };
-
     private:
       ConfigRef               config;
 
