@@ -38,8 +38,6 @@
 #include <Lum/OS/Frame.h>
 #include <Lum/OS/Image.h>
 
-#include <Lum/Prefs/Base.h>
-
 namespace Lum {
   namespace OS {
 
@@ -57,9 +55,9 @@ namespace Lum {
     public:
       static const size_t colorCount = 12; //! Number of predefined colors
       static const size_t fontCount  =  2; //! Number of predefined fonts
-      static const size_t fillCount  = 28; //! Number of predefined fills
-      static const size_t frameCount = 39; //! Number of predefined frames
-      static const size_t imageCount = 29; //! Number of predefined images
+      static const size_t fillCount  = 42; //! Number of predefined fills
+      static const size_t frameCount =  7; //! Number of predefined frames
+      static const size_t imageCount = 31; //! Number of predefined images
 
     protected:
       class LUMAPI Timer
@@ -99,8 +97,8 @@ namespace Lum {
         toolbarButtonBackgroundFillIndex   =  7, //! Background of toolbar button
         scrollButtonBackgroundFillIndex    =  8, //! Background of scroll button
         comboBackgroundFillIndex           =  9, //! Background of combobox
-        entryBackgroundFillIndex           = 10, //! Background of entry fields
-        helpBackgroundFillIndex            = 11, //! Background of tooltips
+        editComboBackgroundFillIndex       = 10,
+        entryBackgroundFillIndex           = 11, //! Background of entry fields
         hprogressBackgroundFillIndex       = 12, //! Background of progress bar
         hprogressFillIndex                 = 13, //! Filled part of progress bar
         vprogressBackgroundFillIndex       = 14, //! Background of progress bar
@@ -109,57 +107,38 @@ namespace Lum {
         vknobBoxFillIndex                  = 17, //! Background of vertical scoll box
         tabBackgroundFillIndex             = 18, //! Background of tab control
         tabRiderBackgroundFillIndex        = 19, //! Background of tab rider
-        columnBackgroundFillIndex          = 20, //! Background of one table column header
-        columnEndBackgroundFillIndex       = 21, //! Background of the area behind the last table column
-        menuStripBackgroundFillIndex       = 22, //! Background of a menu strip
-        menuPulldownBackgroundFillIndex    = 23, //! Background of a pulldown menu (entry in a menu strip)
-        menuEntryBackgroundFillIndex       = 24, //! Background of a menu entry
-        graphBackgroundFillIndex           = 25, //! Background of graph-like controls
-        toolbarBackgroundFillIndex         = 26, //! Background of a toolbar
-        labelBackgroundFillIndex           = 27  //! Background of an label
+        columnBackgroundFillIndex          = 20, //! Background of table column header (for one-column tables)
+        columnLeftBackgroundFillIndex      = 21, //! Background of left table column header
+        columnMiddleBackgroundFillIndex    = 22, //! Background of middle table column header
+        columnRightBackgroundFillIndex     = 23, //! Background of right table column header
+        columnEndBackgroundFillIndex       = 24, //! Background of the area behind the last table column
+        menuStripBackgroundFillIndex       = 25, //! Background of a menu strip
+        menuPulldownBackgroundFillIndex    = 26, //! Background of a pulldown menu (entry in a menu strip)
+        menuEntryBackgroundFillIndex       = 27, //! Background of a menu entry
+        menuWindowBackgroundFillIndex      = 28, //! Background of a menu window
+        popupWindowBackgroundFillIndex     = 29, //! Background of a popup window
+        dialogWindowBackgroundFillIndex    = 30, //! Background of a popup window
+        tooltipWindowBackgroundFillIndex   = 31, //! Background of a popup window
+        graphBackgroundFillIndex           = 32, //! Background of graph-like controls
+        toolbarBackgroundFillIndex         = 33, //! Background of a toolbar
+        labelBackgroundFillIndex           = 34, //! Background of an label
+        listboxBackgroundFillIndex         = 35, //! Background of a listbox (without scrollbars)
+        scrolledBackgroundFillIndex        = 36, //! Background of a scrolled area (including scrollbar)
+        hscrollBackgroundFillIndex         = 37, //! Background of horizontal scrollbar (inkludings croll buttons)
+        vscrollBackgroundFillIndex         = 38, //! Background of vertical scrollbar (inkludings croll buttons)
+        boxedBackgroundFillIndex           = 39, //! Background of boxed content
+        plateBackgroundFillIndex           = 40, //! Background of controls presenting some simple content (e.g. color chooser)
+        statusbarBackgroundFillIndex       = 41  //! Background of the whole status line
       };
 
       enum FrameIndex {
-        buttonFrameIndex          =  0, //! frame for normal buttons
-        positiveButtonFrameIndex  =  1,
-        negativeButtonFrameIndex  =  2,
-        defaultButtonFrameIndex   =  3,
-        toolbarButtonFrameIndex   =  4,
-        scrollButtonFrameIndex    =  5, //! frame for scroll buttons
-        editFrameIndex            =  6, //! frame for single line text fields
-        hprogressFrameIndex       =  7, //! frame of a progress bar
-        vprogressFrameIndex       =  8, //! frame of a progress bar
-        hknobBoxFrameIndex        =  9, //! frame around the knob area of a horizontal scroller element
-        vknobBoxFrameIndex        = 10, //! frame around the knob area of a vertical scroller element
-        hscrollFrameIndex         = 11, //! frame around a horizontal scrollbar
-        vscrollFrameIndex         = 12, //! frame around a vertical scrollbar
-        tabFrameIndex             = 13, //! tab frame
-        tabRiderFrameIndex        = 14, //! frame around a single rider of a tab
-        listboxFrameIndex         = 15, //! frame a round a list box and similar controls
-        scrolledFrameIndex        = 16, //! Frame around scrolled areas
-                                        //! (frame around the scrollable object and the corresponding scrollbars)
-        columnFrameIndex          = 17, //! frame of a single table column header element
-        columnLeftFrameIndex      = 18, //! frame of the first table column header element in a row
-        columnMiddleFrameIndex    = 19, //! frame of not corner table column header element
-        columnRightFrameIndex     = 20, //! frame of the last single table column header element in a row
-        columnEndFrameIndex       = 21, //! frame for the area bhind the last object
-        comboFrameIndex           = 22, //! Display-only combobox frame
-        editComboFrameIndex       = 23, //! Editable combobox frame
-        mainWindowFrameIndex      = 24, //! Frame around main windows
-        menuWindowFrameIndex      = 25, //! Frame around menu windows
-        popupWindowFrameIndex     = 26, //! Frame around popup windows
-        tooltipWindowFrameIndex   = 27, //! Frame around tooltip windows
-        hscaleFrameIndex          = 28, //! Frame around a horizontal slider
-        vscaleFrameIndex          = 29, //! Frame around a vertical slider
-        focusFrameIndex           = 30, //! Frame for showing focus
-        statusbarFrameIndex       = 31, //! Frame around the whole status line
-        statuscellFrameIndex      = 32, //! Frame around a single status cell
-        plateFrameIndex           = 33, //! General frame for control presenting some simple content (color chooser)
-        valuebarFrameIndex        = 34, //! Frame around value bars
-        groupFrameIndex           = 35, //! Frame for grouping a number of elements
-        menuStripFrameIndex       = 36, //! Frame around a menu strip
-        menuPulldownFrameIndex    = 37, //! Frame around a pull down menu (entry ina menu strip)
-        labelFrameIndex           = 38  //! Frame around a label
+        tabFrameIndex             =  0, //! tab frame
+        hscaleFrameIndex          =  1, //! Frame around a horizontal slider
+        vscaleFrameIndex          =  2, //! Frame around a vertical slider
+        focusFrameIndex           =  3, //! Frame for showing focus
+        statuscellFrameIndex      =  4, //! Frame around a single status cell
+        valuebarFrameIndex        =  5, //! Frame around value bars
+        groupFrameIndex           =  6  //! Frame for grouping a number of elements
       };
 
       enum ImageIndex {
@@ -169,10 +148,10 @@ namespace Lum {
         arrowRightImageIndex       =  3, //! Image of a arrow pointing to the right side
         arrowUpImageIndex          =  4, //! Image of a arrow pointing up
         arrowDownImageIndex        =  5, //! Image of a arrow pointing down
-        arrowScrollLeftImageIndex  =  6, //! Image of a arrow for scroll bars pointing to the left side
-        arrowScrollRightImageIndex =  7, //! Image of a arrow for scroll bars pointing to the right side
-        arrowScrollUpImageIndex    =  8, //! Image of a arrow for scroll bars pointing up
-        arrowScrollDownImageIndex  =  9, //! Image of a arrow for scroll bars pointing down
+        scrollLeftImageIndex       =  6, //! Image for scroll bar button (left)
+        scrollRightImageIndex      =  7, //! Image for scroll bar button (right)
+        scrollUpImageIndex         =  8, //! Image for scroll bar button (up)
+        scrollDownImageIndex       =  9, //! Image for scroll bar button (down)
         comboImageIndex            = 10, //! Image for read only combo box popup (normally just an arrow)
         comboEditButtonImageIndex  = 11, //! Image for editable combo box popup (normally just an arrow)
         comboDividerImageIndex     = 12, //! Divider between content and image
@@ -191,7 +170,9 @@ namespace Lum {
         negativeImageIndex         = 25, //! Image for marking a negative action (e.g. for a button)
         defaultImageIndex          = 26, //! Image for marking a default action (e.g. for a button)
         helpImageIndex             = 27, //! Image for marking a help action (e.g. for a button)
-        closeImageIndex            = 28  //! Image for closing widget
+        closeImageIndex            = 28, //! Image for closing widget
+        hpaneHandleImageIndex      = 29, //! Grip object for the pane control
+        vpaneHandleImageIndex      = 30  //! Grip object for the pane control
       };
 
       enum FontScale {
@@ -247,22 +228,6 @@ namespace Lum {
         bigEndian
       };
 
-      /**
-        Display-specific preferences
-      */
-      class Prefs : public ::Lum::Prefs::Prefs
-      {
-      public:
-        std::string  propFont;
-        std::string  fixedFont;
-        size_t       propFontSize;
-        size_t       fixedFontSize;
-        std::wstring theme;
-
-      public:
-        Prefs();
-      };
-
     public:
       /**
         @name (De)initialisation
@@ -430,6 +395,11 @@ namespace Lum {
         Clear the operating system global clipboard.
       */
       virtual void ClearClipboard() = 0;
+
+      /**
+        Returns true, if there is data available in the clipboard.
+       */
+      virtual bool HasClipboard() const = 0;
       //@}
 
       /**
@@ -523,15 +493,6 @@ namespace Lum {
       virtual size_t GetArgCount() const = 0;
       virtual std::wstring GetArg(size_t pos) const = 0;
 
-      /**
-        @name references
-        Methods for dealing with preferences.
-      */
-      //@{
-      virtual std::wstring GetPrefsPath() const = 0;
-      virtual std::wstring GetPrefsName() const = 0;
-      //@}
-
       /**
         @name Theming
         Methods for dealing with themes.
