@@ -31,7 +31,6 @@
 #include <Lum/OS/DrawInfo.h>
 #include <Lum/OS/Event.h>
 #include <Lum/OS/Fill.h>
-#include <Lum/OS/Frame.h>
 #include <Lum/OS/Window.h>
 
 namespace Lum {
@@ -99,30 +98,9 @@ namespace Lum {
   */
   class LUMAPI Object : public Base::DnDObject
   {
-  public:
-
-    /**
-     Special Preferences object for graphical objects.
-    */
-    class LUMAPI Prefs : public Lum::Prefs::Prefs
-    {
-    public:
-      OS::FillRef  background;
-      OS::FrameRef frame;
-      Base::Size   hSize; //! Value to fixate the horizontal size of the object
-      Base::Size   vSize; //! Value to fixate the vertical size of the object
-
-    public:
-      Prefs(const std::wstring& name=L"");
-
-      void Initialize();
-    };
-
   protected:
     Object              *parent;        //! The parent object, may be NULL for top level objects.
 
-    Prefs               *prefs;         //! Preferences of this object
-
     /**
       @name Internal position and dimension.
       The objects internal (without outer frame) minimal, current and maximal dimension.
@@ -169,13 +147,12 @@ namespace Lum {
     */
     //@{
     OS::FillRef         background;    //! The object background. \see Object::SetBackground
-    OS::FrameRef        frame;         //! The object frame. \see Object::SetFrame
     //@}
 
     bool                horizontalFlex,verticalFlex;
     bool                visible;       //! The object is currently visible
     bool                firstDraw;     //! If true, this is the first drawing of the widget
-    bool                layouted;      //! The object has already calculated its layout
+    bool                layouted;      //! The object has calculated its layout (can be reseted by move/resize)
 
   private:
     /**
@@ -191,8 +168,8 @@ namespace Lum {
     bool                requestsKeyboard; //! The control requests keyboard input
     //@}
 
-    bool                canDrawMouseActive; //! Does draw itself different if is active
     bool                mouseActive;   //! Is currently activated by mouse
+    bool                redrawOnMouseActive; //! If set (default) redraw object if it gets mouse active
 
   public:
     bool                inited;        //! Has been initialized
@@ -228,11 +205,11 @@ namespace Lum {
     virtual void RequestFocus();
     virtual void UnrequestFocus();
 
+    virtual void SetRedrawOnMouseActive(bool redraw);
+
   public:
     virtual ~Object();
 
-    virtual void SetPrefs(Prefs* prefs);
-
     virtual void SetController(Controller* controller);
 
     /**
@@ -251,6 +228,17 @@ namespace Lum {
     virtual size_t GetOMaxHeight() const;
     //@}
 
+    /**
+      @name object border
+      Methods returning the border size (frame) of the object.
+    */
+    //@{
+    virtual size_t GetTopBorder() const;
+    virtual size_t GetBottomBorder() const;
+    virtual size_t GetLeftBorder() const;
+    virtual size_t GetRightBorder() const;
+    //@}
+
     /**
       @name Baseline support
       Method that return information about the vertical position
@@ -316,6 +304,7 @@ namespace Lum {
 
     virtual void SetMenu(OS::Window* window);
     virtual OS::Window* GetMenu() const;
+    virtual void PrepareMenu();
     //@}
 
     /**
@@ -393,6 +382,7 @@ namespace Lum {
     */
     //@{
     virtual void SetBackground(OS::Fill* background);
+    virtual OS::Fill* GetBackground() const;
 
     virtual void DrawBackground(int x, int y, size_t w, size_t h);
     virtual void DrawParentBackground(int x, int y, size_t w, size_t h);
@@ -400,12 +390,6 @@ namespace Lum {
                                             int x, int y, size_t w, size_t h);
     virtual void DrawParentBackgroundWithDrawInfo(OS::DrawInfo* draw,
                                                   int x, int y, size_t w, size_t h);
-    virtual void DrawBackgroundRelative(OS::DrawInfo* draw,
-                                        OS::Fill* background,
-                                        int x, int y, size_t w, size_t h);
-    virtual void SetFrame(OS::Frame* frame);
-    virtual OS::Frame* GetFrame() const;
-
     virtual OS::Color GetTextColor(OS::DrawInfo *draw) const;
     //@}
 
@@ -423,8 +407,6 @@ namespace Lum {
       @name MouseActive methods
     */
     //@{
-    virtual void SetCanDrawMouseActive(bool canDraw);
-    virtual bool CanDrawMouseActive() const;
     virtual void MouseActive();
     virtual void MouseInactive();
     virtual bool IsMouseActive() const;
@@ -530,6 +512,9 @@ namespace Lum {
 
     bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
+    bool HasBaseline() const;
+    size_t GetBaseline() const;
+
     void Layout();
     void Draw(int x, int y, size_t w, size_t h);
     void Hide();
@@ -550,6 +535,9 @@ namespace Lum {
 
     bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
+    bool HasBaseline() const;
+    size_t GetBaseline() const;
+
     void Layout();
     void Draw(int x, int y, size_t w, size_t h);
     void Hide();
