@@ -73,16 +73,6 @@ namespace Lum {
     };
 
   public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      bool baseline;
-
-    public:
-      Prefs();
-      void Initialize();
-    };
-
     class Controller : public ::Lum::Controller
     {
     public:
@@ -94,6 +84,7 @@ namespace Lum {
   private:
     Alignment        textAlign;        //! Alignment of text
     size_t           textWidth;        //! Maximum size of text to be entered
+    bool             baseline;         //! Draw the baseline (TODO: Move to theme)
 
     int              visWidth;         //! Visible with of the control in pixel
     int              offset;
@@ -213,6 +204,8 @@ namespace Lum {
     void CatchedFocus();
     void LostFocus();
 
+    void PrepareMenu();
+
     bool HandleMouseEvent(const OS::MouseEvent& event);
     bool HandleKeyEvent(const OS::KeyEvent& event);
 
