@@ -20,6 +20,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
+#include <Lum/Model/Action.h>
 #include <Lum/Model/Header.h>
 #include <Lum/Model/Selection.h>
 
@@ -33,14 +34,6 @@ namespace Lum {
 
   class LUMAPI Table : public Group
   {
-  public:
-    class Prefs : public Group::Prefs
-    {
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   private:
     Object           *object;
     Scroller         *hScroller;
@@ -53,6 +46,7 @@ namespace Lum {
     Header           *header;
     Model::HeaderRef headerModel;
     bool             showHeader;
+    Model::ActionRef refreshAction;
 
   public:
     Table();
