@@ -30,14 +30,6 @@ namespace Lum {
   */
   class LUMAPI Toggle : public State
   {
-  public:
-    class Prefs : public State::Prefs
-    {
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   private:
     Object *label;
 
