@@ -24,8 +24,6 @@
 
 namespace Lum {
 
-  static Blender::Prefs* prefs=new Blender::Prefs(L"Blender");
-
   /**
     Hidden class used internally by Blender for display of pseudo dialogs.
   */
@@ -71,7 +69,6 @@ namespace Lum {
     }
 
     main->SetParent(this);
-    SetPrefs(::Lum::prefs);
     // TODO: Reset background and frame
   }
 
@@ -121,18 +118,10 @@ namespace Lum {
     Group::Layout();
   }
 
-  Blender::Prefs::Prefs(const std::wstring& name)
-    : Group::Prefs(name)
-  {
-    // no code
-  }
-
   Blender::Blender()
   : top(NULL),main(NULL),bottom(NULL),
      closeTopAction(new Model::Action()),closeBottomAction(new Model::Action())
   {
-    SetPrefs(::Lum::prefs);
-
     AttachModel(closeTopAction);
     AttachModel(closeBottomAction);
   }
