@@ -1,5 +1,3 @@
-#include <Lum/Button.h>
-
 /*
   This source is part of the Illumination library
   Copyright (C) 2004  Tim Teulings
@@ -19,74 +17,38 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
+#include <Lum/Button.h>
+
 #include <Lum/Base/DateTime.h>
 
 #include <Lum/OS/Theme.h>
 
 #include <Lum/Dialog.h>
 #include <Lum/Text.h>
-#include <iostream>
-namespace Lum {
 
-  static Button::Prefs *prefs=new Button::Prefs();
+namespace Lum {
 
   static size_t pulseSec  = 0;      // Make this a global preference value
   static size_t pulseMSec = 100000;
 
-  Button::Prefs::Prefs()
-  : Object::Prefs(L"Button")
-  {
-    // no code
-  }
-
-  void Button::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    frame=OS::display->GetFrame(OS::Display::buttonFrameIndex);
-    background=OS::display->GetFill(OS::Display::buttonBackgroundFillIndex);
-
-    returnFrame=OS::display->GetFrame(OS::Display::positiveButtonFrameIndex);
-    bgReturn=OS::display->GetFill(OS::Display::positiveButtonBackgroundFillIndex);
-
-    escapeFrame=OS::display->GetFrame(OS::Display::negativeButtonFrameIndex);
-    bgEscape=OS::display->GetFill(OS::Display::negativeButtonBackgroundFillIndex);
-
-    defaultFrame=OS::display->GetFrame(OS::Display::defaultButtonFrameIndex);
-    bgDefault=OS::display->GetFill(OS::Display::defaultButtonBackgroundFillIndex);
-
-    toolbarFrame=OS::display->GetFrame(OS::Display::toolbarButtonFrameIndex);
-    bgToolbar=OS::display->GetFill(OS::Display::toolbarButtonBackgroundFillIndex);
-
-    scrollFrame=OS::display->GetFrame(OS::Display::scrollButtonFrameIndex);
-    bgScroll=OS::display->GetFill(OS::Display::scrollButtonBackgroundFillIndex);
-
-    iFrame=frame;
-
-    sHSpace.SetSize(Base::Size::softUnitP,25);
-    sVSpace.SetSize(Base::Size::softUnitP,25);
-  }
-
   Button::Button()
   : object(NULL),font(OS::display->GetFont()),type(typeNormal),
     pulse(false),shortCut('\0'),scAssigned(false)
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
 
     SetCanFocus(true);
-    SetCanDrawMouseActive(true);
-
-    RequestFocus();
+    SetRedrawOnMouseActive(true);
   }
 
   Button::Button(Object* object)
   : object(NULL),font(OS::display->GetFont()),type(typeNormal),
     pulse(false),shortCut('\0'),scAssigned(false)
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
 
     SetCanFocus(true);
-    SetCanDrawMouseActive(true);
+    SetRedrawOnMouseActive(true);
 
     SetLabel(object);
   }
@@ -95,10 +57,10 @@ namespace Lum {
   : object(NULL),font(OS::display->GetFont()),type(typeNormal),
     pulse(false),shortCut('\0'),scAssigned(false)
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
 
     SetCanFocus(true);
-    SetCanDrawMouseActive(true);
+    SetRedrawOnMouseActive(true);
 
     SetText(text);
   }
@@ -117,7 +79,7 @@ namespace Lum {
   {
     assert(inited && object!=NULL && object->HasBaseline());
 
-    return frame->topBorder+object->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
+    return background->topBorder+object->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
   }
 
   /**
@@ -218,36 +180,35 @@ namespace Lum {
     /* Let the frame calculate its size */
     switch (type) {
       case typeNormal:
-      /*
-      SetFrame(prefs->frame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->background);*/
+      SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
+      RequestFocus();
       break;
     case typeDefault:
-      SetFrame(dynamic_cast<Prefs*>(prefs)->defaultFrame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->bgDefault);
+      SetBackground(OS::display->GetFill(OS::Display::defaultButtonBackgroundFillIndex));
       image=OS::display->GetImage(OS::Display::defaultImageIndex);
+      RequestFocus();
       break;
     case typeCommit:
-      SetFrame(dynamic_cast<Prefs*>(prefs)->returnFrame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->bgReturn);
+      SetBackground(OS::display->GetFill(OS::Display::positiveButtonBackgroundFillIndex));
       image=OS::display->GetImage(OS::Display::positiveImageIndex);
+      RequestFocus();
       break;
     case typeCancel:
-      SetFrame(dynamic_cast<Prefs*>(prefs)->escapeFrame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->bgEscape);
+      SetBackground(OS::display->GetFill(OS::Display::negativeButtonBackgroundFillIndex));
       image=OS::display->GetImage(OS::Display::negativeImageIndex);
+      RequestFocus();
       break;
     case typeImage:
-      SetFrame(dynamic_cast<Prefs*>(prefs)->iFrame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->background);
+      SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
+      RequestFocus();
       break;
     case typeToolBar:
-      SetFrame(dynamic_cast<Prefs*>(prefs)->toolbarFrame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->bgToolbar);
+      SetBackground(OS::display->GetFill(OS::Display::toolbarButtonBackgroundFillIndex));
+      SetCanFocus(false);
       break;
     case typeScroll:
-      SetFrame(dynamic_cast<Prefs*>(prefs)->scrollFrame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->bgScroll);
+      SetBackground(OS::display->GetFill(OS::Display::scrollButtonBackgroundFillIndex));
+      SetCanFocus(false);
       break;
     }
 
@@ -278,10 +239,10 @@ namespace Lum {
 
     switch (type) {
     case typeImage:
-      minWidth+=dynamic_cast<Prefs*>(prefs)->sHSpace.GetSize()*2;
-      width+=dynamic_cast<Prefs*>(prefs)->sHSpace.GetSize()*2;
-      minHeight+=dynamic_cast<Prefs*>(prefs)->sVSpace.GetSize()*2;
-      height+=dynamic_cast<Prefs*>(prefs)->sVSpace.GetSize()*2;
+      minWidth+=Base::GetSize(Base::Size::softUnitP,25)*2;
+      width+=Base::GetSize(Base::Size::softUnitP,25)*2;
+      minHeight+=Base::GetSize(Base::Size::softUnitP,25)*2;
+      height+=Base::GetSize(Base::Size::softUnitP,25)*2;
       break;
     case typeScroll:
       // No space around object
@@ -409,10 +370,10 @@ namespace Lum {
 
     switch (type) {
     case typeImage:
-      x+=dynamic_cast<Prefs*>(prefs)->sHSpace.GetSize();
-      y+=dynamic_cast<Prefs*>(prefs)->sHSpace.GetSize();
-      width-=2*dynamic_cast<Prefs*>(prefs)->sHSpace.GetSize();
-      height-=2*dynamic_cast<Prefs*>(prefs)->sHSpace.GetSize();
+      x+=Base::GetSize(Base::Size::softUnitP,25);
+      y+=Base::GetSize(Base::Size::softUnitP,25);
+      width-=2*Base::GetSize(Base::Size::softUnitP,25);
+      height-=2*Base::GetSize(Base::Size::softUnitP,25);
       break;
     case typeScroll:
       break;
@@ -429,16 +390,21 @@ namespace Lum {
 
     if (object!=NULL) {
       object->Resize(width,height);
-    }
-
-    object->Move(x+(width-object->GetOWidth()) / 2,
+      object->Move(x+(width-object->GetOWidth()) / 2,
                  y+(height-object->GetOHeight()) / 2);
+    }
 
     Control::Layout();
   }
 
   void Button::Draw(int x, int y, size_t w, size_t h)
   {
+    Control::Draw(x,y,w,h); /* We must call Draw of our superclass */
+
+    if (!OIntersect(x,y,w,h)) {
+      return;
+    }
+
     OS::DrawInfo *draw=GetDrawInfo();
 
     /*
@@ -459,33 +425,7 @@ namespace Lum {
 
     draw->focused=HasFocus();
 
-    Control::Draw(x,y,w,h); /* We must call Draw of our superclass */
-
-    if (!Intersect(x,y,w,h)) {
-      draw->activated=false;
-      draw->selected=false;
-      draw->disabled=false;
-      draw->focused=false;
-      return;
-    }
-
-    /*
-      We fill the entier region with the background color, extracting
-      the region that will be covered by the image object.
-    */
-
-    draw->PushClipBegin(this->x,this->y,width,height);
-    if (object!=NULL) {
-      draw->SubClipRegion(object->GetOX(),object->GetOY(),
-                          object->GetOWidth(),object->GetOHeight());
-    }
-    if (image.Valid() && OS::display->GetTheme()->ShowButtonImages() && !image->GetAlpha()) {
-      draw->SubClipRegion(imageX,imageY,
-                          image->GetWidth(),image->GetHeight());
-    }
-    draw->PushClipEnd();
     DrawBackground(x,y,w,h);
-    draw->PopClip();
 
     // Draw object
     if (object!=NULL) {
