@@ -23,51 +23,18 @@
 #include <Lum/Text.h>
 
 namespace Lum {
-  static Combo::Prefs *prefs= new Combo::Prefs();
-
-  Combo::Prefs::Prefs()
-  : Control::Prefs(L"Combo")
-  {
-    // no code
-  }
-
-  void Combo::Prefs::Initialize()
-  {
-    Control::Prefs::Initialize();
-
-    background=OS::display->GetFill(OS::Display::comboBackgroundFillIndex);
-
-    readOnlyFrame=OS::display->GetFrame(OS::Display::comboFrameIndex);
-    readOnlyImage=OS::display->GetImage(OS::Display::comboImageIndex);
-    divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
-
-    editableFrame=OS::display->GetFrame(OS::Display::editComboFrameIndex);
-    buttonImage=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
-
-    imageRight=true;
-  }
 
   Combo::Table::Table()
-  : success(false),
-    commit(new Model::Action())
+  : success(false)
   {
     AttachModel(GetMouseSelectionAction());
-    AttachModel(commit);
   }
 
   Combo::Table::~Table()
   {
-    UnattachModel(commit);
     UnattachModel(GetMouseSelectionAction());
   }
 
-  void Combo::Table::CalcSize()
-  {
-    dynamic_cast<Dialog*>(GetWindow()->GetMaster())->RegisterCommitShortcut(this,commit);
-
-    TableView::CalcSize();
-  }
-
   void Combo::Table::Resync(Base::Model* model,
                             const Base::ResyncMsg& msg)
   {
@@ -75,17 +42,14 @@ namespace Lum {
       success=true;
       GetWindow()->Exit();
     }
-    else if (model==commit && commit->IsFinished()) {
-      success=true;
-      GetWindow()->Exit();
-    }
     else {
       TableView::Resync(model,msg);
     }
   }
 
   Combo::Combo(Object* value, bool editable)
-  : editable(editable),
+  : imageRight(true),
+    editable(editable),
     table(NULL),
     popup(NULL),
     prevAction(new Lum::Model::Action()),
@@ -94,9 +58,16 @@ namespace Lum {
     selection(new Model::SingleLineSelection()),
     value(value)
   {
+    if (editable) {
+      SetBackground(OS::display->GetFill(OS::Display::editComboBackgroundFillIndex));
+    }
+    else {
+      SetBackground(OS::display->GetFill(OS::Display::comboBackgroundFillIndex));
+    }
+
     SetCanFocus(true);
     RequestFocus();
-    SetCanDrawMouseActive(true);
+    SetRedrawOnMouseActive(true);
 
     value->SetParent(this);
 
@@ -104,8 +75,6 @@ namespace Lum {
       value->SetBackground(NULL);
     }
 
-    SetPrefs(::Lum::prefs);
-
     AttachModel(prevAction);
     AttachModel(nextAction);
   }
@@ -127,7 +96,12 @@ namespace Lum {
   {
     if (value!=NULL && value->HasBaseline()) {
       // We also assume that is vertically flexible
-      return frame->topBorder+value->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
+      if (background.Valid()) {
+        return background->topBorder+value->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
+      }
+      else {
+        return value->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
+      }
     }
     else {
       return 0;
@@ -176,21 +150,20 @@ namespace Lum {
       UnrequestFocus();
     }
 
+    /*
     if (editable) {
-      SetFrame(dynamic_cast<Prefs*>(prefs)->editableFrame);
-      if (frame->minHeight>0 || frame->minWidth>0) {
+      if (background.Valid() && background->HasBorder()) {
         value->SetFrame(new OS::EmptyFrame());
       }
-    }
-    else {
-      SetFrame(dynamic_cast<Prefs*>(prefs)->readOnlyFrame);
-    }
+    }*/
 
     value->SetFlex(true,true);
     value->CalcSize();
 
     if (editable) {
-      minWidth=dynamic_cast<Prefs*>(prefs)->buttonImage->GetWidth();
+      OS::ImageRef image=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
+
+      minWidth=image->GetWidth();
 
       width=minWidth;
 
@@ -198,23 +171,26 @@ namespace Lum {
       minWidth+=value->GetOWidth();
 
       minHeight=std::max(value->GetOMinHeight(),
-                         dynamic_cast<Prefs*>(prefs)->buttonImage->GetHeight());
+                         image->GetHeight());
       height=std::max(value->GetOHeight(),
-                      dynamic_cast<Prefs*>(prefs)->buttonImage->GetHeight());
+                      image->GetHeight());
     }
     else {
+      OS::ImageRef image=OS::display->GetImage(OS::Display::comboImageIndex);
+      OS::ImageRef divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
+
       minWidth=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
-               dynamic_cast<Prefs*>(prefs)->divider->GetWidth()+
+               divider->GetWidth()+
                OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
-               dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth();
+               image->GetWidth();
 
       width=minWidth;
 
       minWidth+=value->GetOMinWidth();
       minWidth+=value->GetOWidth();
 
-      minHeight=std::max(value->GetOMinHeight(),dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
-      height=std::max(value->GetOHeight(),dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
+      minHeight=std::max(value->GetOMinHeight(),image->GetHeight());
+      height=std::max(value->GetOHeight(),image->GetHeight());
     }
 
     Control::CalcSize();
@@ -267,6 +243,8 @@ namespace Lum {
     }
     combo->table->GetTableView()->SetAutoHSize(true);
     combo->table->GetTableView()->SetAutoVSize(true);
+    dynamic_cast<Dialog*>(GetWindow()->GetMaster())->RegisterCommitShortcut(combo->table->GetTableView(),
+                                                                            combo->table->GetTableView()->GetMouseSelectionAction());
 
     combo->InitTable(combo->table);
 
@@ -357,31 +335,36 @@ namespace Lum {
   void Combo::Layout()
   {
     if (editable) {
-      value->Resize(width-dynamic_cast<Prefs*>(prefs)->buttonImage->GetWidth(),height);
+      OS::ImageRef image=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
 
-      if (dynamic_cast<Prefs*>(prefs)->imageRight) {
+      value->Resize(width-image->GetWidth(),height);
+
+      if (imageRight) {
         value->Move(x,y+(height-value->GetOHeight()) / 2);
       }
       else {
-        value->Move(x+dynamic_cast<Prefs*>(prefs)->buttonImage->GetWidth(),
+        value->Move(x+image->GetWidth(),
                     y+(height-value->GetOHeight()) / 2);
       }
     }
     else {
+      OS::ImageRef image=OS::display->GetImage(OS::Display::comboImageIndex);
+      OS::ImageRef divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
+
       value->Resize(width-
-                    dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()-
+                    image->GetWidth()-
                     2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
-                    dynamic_cast<Prefs*>(prefs)->divider->GetWidth(),
+                    divider->GetWidth(),
                     height-2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder));
 
-      if (dynamic_cast<Prefs*>(prefs)->imageRight) {
+      if (imageRight) {
         value->Move(x,
                     y+(height-value->GetOHeight()) / 2);
       }
       else {
-        value->Move(x+dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
+        value->Move(x+image->GetWidth()+
                     2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
-                     dynamic_cast<Prefs*>(prefs)->divider->GetWidth(),
+                     divider->GetWidth(),
                     y+(height-value->GetOHeight()) / 2);
       }
     }
@@ -405,13 +388,15 @@ namespace Lum {
     draw->focused=false;
     draw->disabled=!(GetModel()!=NULL) || GetModel()->IsNull() || !GetModel()->IsEnabled();
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
     /* --- */
 
     if (editable) {
+      OS::ImageRef image=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
+
       value->Draw(x,y,w,h);
 
       if (IsMouseActive()) {
@@ -420,28 +405,37 @@ namespace Lum {
 
       draw->focused=HasFocus();
 
-      if (dynamic_cast<Prefs*>(prefs)->imageRight) {
+      draw->PushClipBegin(x,y,w,h);
+      draw->SubClipRegion(value->GetOX(),value->GetOY(),value->GetOWidth(),value->GetOHeight());
+      draw->PushClipEnd();
+      DrawBackground(x,y,w,h);
+      draw->PopClip();
+
+      if (imageRight) {
         int    bx,by;
         size_t bw,bh;
 
         bx=this->x+value->GetOWidth();
-        by=y;
-        bw=dynamic_cast<Prefs*>(prefs)->buttonImage->GetWidth();
+        by=this->y;
+        bw=image->GetWidth();
         bh=height;
 
-        dynamic_cast<Prefs*>(prefs)->buttonImage->Draw(draw,
-                                                       bx,by,
-                                                       dynamic_cast<Prefs*>(prefs)->buttonImage->GetWidth(),
-                                                       height);
+        image->Draw(draw,
+                    bx,by,
+                    image->GetWidth(),
+                    height);
       }
       else {
-        dynamic_cast<Prefs*>(prefs)->buttonImage->Draw(draw,
-                                                       this->x,this->y,
-                                                       dynamic_cast<Prefs*>(prefs)->buttonImage->GetWidth(),
-                                                       height);
+        image->Draw(draw,
+                    this->x,this->y,
+                    image->GetWidth(),
+                    height);
       }
     }
     else {
+      OS::ImageRef image=OS::display->GetImage(OS::Display::comboImageIndex);
+      OS::ImageRef divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
+
       if (IsMouseActive()) {
         draw->activated=true;
       }
@@ -456,36 +450,36 @@ namespace Lum {
 
       value->Draw(x,y,w,h);
 
-      if (dynamic_cast<Prefs*>(prefs)->imageRight) {
-        dynamic_cast<Prefs*>(prefs)->divider->Draw(draw,
-                                                   this->x+width-
-                                                   dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()-
-                                                   OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
-                                                   dynamic_cast<Prefs*>(prefs)->divider->GetWidth(),
-                                                   this->y,
-                                                   dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                   height);
+      if (imageRight) {
+        divider->Draw(draw,
+                      this->x+width-
+                      image->GetWidth()-
+                      OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
+                      divider->GetWidth(),
+                      this->y,
+                      image->GetWidth(),
+                      height);
 
-        dynamic_cast<Prefs*>(prefs)->readOnlyImage->Draw(draw,
-                                                         this->x+width-
-                                                         dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                         this->y+(height-dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight()) / 2,
-                                                         dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                         dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
+        image->Draw(draw,
+                    this->x+width-
+                    image->GetWidth(),
+                    this->y+(height-image->GetHeight()) / 2,
+                    image->GetWidth(),
+                    image->GetHeight());
       }
       else {
-        dynamic_cast<Prefs*>(prefs)->readOnlyImage->Draw(draw,
-                                                         x,
-                                                         y+(height-dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight()) / 2,
-                                                         dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                         dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
+        image->Draw(draw,
+                    x,
+                    y+(height-image->GetHeight()) / 2,
+                    image->GetWidth(),
+                    image->GetHeight());
 
-        dynamic_cast<Prefs*>(prefs)->divider->Draw(draw,
-                                                   x+dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
-                                                   OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
-                                                   this->y,
-                                                   dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                   height);
+        divider->Draw(draw,
+                      x+image->GetWidth()+
+                      OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
+                      this->y,
+                      image->GetWidth(),
+                      height);
 
       }
     }
