@@ -24,21 +24,6 @@
 #include <time.h>
 
 namespace Lum {
-  static DatePicker::Prefs* prefs=new DatePicker::Prefs();
-
-  DatePicker::Prefs::Prefs()
-  : Object::Prefs(L"DatePicker")
-  {
-    // no code
-  }
-
-  void DatePicker::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    background=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
-    frame=new OS::EmptyFrame();
-  }
 
   DatePicker::DatePicker()
   : prevYear(new Model::Action()),
@@ -47,7 +32,7 @@ namespace Lum {
     nextYear(new Model::Action()),
     select(new Model::Action())
   {
-    SetPrefs(Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::tableBackgroundFillIndex));
 
     SetCanFocus(true);
     RequestFocus();
