@@ -23,19 +23,10 @@
 #include <Lum/PopupGroup.h>
 
 namespace Lum {
-  static DateSelect::Prefs *prefs= new DateSelect::Prefs();
-
-  DateSelect::Prefs::Prefs()
-  : PopupControl::Prefs(L"DateSelect")
-  {
-    // no code
-  }
 
   DateSelect::DateSelect()
   : PopupControl(new DateView()),popup(NULL)
   {
-    SetPrefs(Lum::prefs);
-
     SetCanFocus(true);
     RequestFocus();
   }
