@@ -28,27 +28,11 @@
 #include <Lum/OS/KeyboardHandler.h>
 #include <Lum/OS/Theme.h>
 
-#include <Lum/FrameGroup.h>
+#include <Lum/Panel.h>
 
 #define MENU_TIMEOUT 2
 
 namespace Lum {
-  static Dialog::Prefs *prefs=new Dialog::Prefs(L"Dialog");
-
-  Dialog::Prefs::Prefs(const std::wstring& name)
-    : ::Lum::Prefs::Prefs(name)
-  {
-    // no code
-  }
-
-  void Dialog::Prefs::Initialize()
-  {
-    mainFrame=OS::display->GetFrame(OS::Display::mainWindowFrameIndex);
-    menuFrame=OS::display->GetFrame(OS::Display::menuWindowFrameIndex);
-    popupFrame=OS::display->GetFrame(OS::Display::popupWindowFrameIndex);
-    tooltipFrame=OS::display->GetFrame(OS::Display::tooltipWindowFrameIndex);
-  }
-
   /**
     Checks if the given shortcut entry matches the given key.
   */
@@ -352,8 +336,7 @@ namespace Lum {
   }
 
   Dialog::Dialog()
-  : prefs(::Lum::prefs),
-    top(NULL),
+  : top(NULL),
     mouseGrab(NULL),
     mouseActive(NULL),
     reference(NULL),
@@ -511,46 +494,46 @@ namespace Lum {
 
   void Dialog::CalcSize()
   {
-    FrameGroup *frame; // overloading member variable
+    Panel *panel; // overloading member variable
 
-    frame=new FrameGroup();
+    panel=new HPanel();
 
     switch (window->GetType()) {
     case OS::Window::typeTooltip:
-      frame->SetFrame(prefs->tooltipFrame);
+      panel->SetBackground(OS::display->GetFill(OS::Display::tooltipWindowBackgroundFillIndex));
       break;
     case OS::Window::typeMenu:
-      frame->SetFrame(prefs->menuFrame);
+      panel->SetBackground(OS::display->GetFill(OS::Display::menuWindowBackgroundFillIndex));
       break;
     case OS::Window::typePopup:
     case OS::Window::typeSplash:
-      frame->SetFrame(prefs->popupFrame);
+      panel->SetBackground(OS::display->GetFill(OS::Display::popupWindowBackgroundFillIndex));
       break;
     case OS::Window::typeMain:
-      frame->SetFrame(prefs->mainFrame);
+      panel->SetBackground(OS::display->GetFill(OS::Display::dialogWindowBackgroundFillIndex));
       break;
     default:
-      frame->SetFrame(new OS::EmptyFrame());
+      //panel->SetBackground(OS::display->GetFill(OS::Display::dialogWindowBackgroundFillIndex));
+      break;
     }
 
-    frame->SetFlex(top->HorizontalFlex(),top->VerticalFlex());
-    frame->SetSpace(false);
-    frame->SetObject(top);
-    frame->SetWindow(window);
+    panel->SetFlex(top->HorizontalFlex(),top->VerticalFlex());
+    panel->Add(top);
+    panel->SetWindow(window);
 
-    frame->CalcSize();
+    panel->CalcSize();
 
     if (window->GetType()==OS::Window::typePopup && reference!=NULL) {
       // Is is nice, when reference and popup have the same width
-      if (reference->GetOWidth()>frame->GetOWidth()) {
-        frame->ResizeWidth(reference->GetOWidth());
+      if (reference->GetOWidth()>panel->GetOWidth()) {
+        panel->ResizeWidth(reference->GetOWidth());
       }
     }
     else if (OS::display->GetType()==OS::Display::typeTextual && window->GetType()==OS::Window::typeMain) {
-      frame->Resize(OS::display->GetWorkAreaWidth(),OS::display->GetWorkAreaHeight());
+      panel->Resize(OS::display->GetWorkAreaWidth(),OS::display->GetWorkAreaHeight());
     }
 
-    window->SetSize(frame->GetOWidth(),frame->GetOHeight());
+    window->SetSize(panel->GetOWidth(),panel->GetOHeight());
 
     if (window->GetX()+window->GetWidth()-1>OS::display->GetScreenWidth()
         && window->GetWidth()<OS::display->GetScreenWidth()) {
@@ -563,25 +546,25 @@ namespace Lum {
                      OS::display->GetScreenHeight()-window->GetHeight());
     }
 
-    if (frame->HorizontalFlex()) {
-      window->SetMinWidth(frame->GetOMinWidth());
-      window->SetMaxWidth(frame->GetOMaxWidth());
+    if (panel->HorizontalFlex()) {
+      window->SetMinWidth(panel->GetOMinWidth());
+      window->SetMaxWidth(panel->GetOMaxWidth());
     }
     else {
       window->SetMinWidth(window->GetWidth());
       window->SetMaxWidth(window->GetWidth());
     }
 
-    if (frame->VerticalFlex()) {
-      window->SetMinHeight(frame->GetOMinHeight());
-      window->SetMaxHeight(frame->GetOMaxHeight());
+    if (panel->VerticalFlex()) {
+      window->SetMinHeight(panel->GetOMinHeight());
+      window->SetMaxHeight(panel->GetOMaxHeight());
     }
     else {
       window->SetMinHeight(window->GetHeight());
       window->SetMaxHeight(window->GetHeight());
     }
 
-    this->frame=frame;
+    this->frame=panel;
   }
 
 
@@ -640,6 +623,7 @@ namespace Lum {
 
       menu=object->GetMenu();
       if (menu!=NULL) {
+        object->PrepareMenu();
         /* ignore */ menu->Open(true);
         return true;
       }
@@ -939,10 +923,10 @@ namespace Lum {
 
       if (window->GetType()==OS::Window::typeMain) {
         if (window->IsFullScreen()) {
-          frame->SetFrame(new OS::EmptyFrame());
+          frame->SetBackground(OS::display->GetFill(OS::Display::backgroundFillIndex));
         }
         else {
-          frame->SetFrame(prefs->mainFrame);
+          frame->SetBackground(OS::display->GetFill(OS::Display::dialogWindowBackgroundFillIndex));
         }
       }
 
