@@ -96,6 +96,8 @@ namespace Lum {
         table->GetTableView()->SetAutoFitColumns(true);
         table->GetTableView()->SetAutoHSize(true);
         table->GetTableView()->SetAutoVSize(true);
+        dynamic_cast<Dialog*>(GetWindow()->GetMaster())->RegisterCommitShortcut(table->GetTableView(),
+                                                                                table->GetTableView()->GetMouseSelectionAction());
 
         container->SetMain(table);
 
