@@ -31,8 +31,6 @@
 namespace Lum {
   namespace Edit {
 
-    static Edit::Prefs*  prefs(new Edit::Prefs);
-
     /**
       Expand LineInfo to also cover the new position.
 
@@ -109,19 +107,6 @@ namespace Lum {
       this->decoration[x]|=decoration;
     }
 
-    Edit::Prefs::Prefs()
-    : Scrollable::Prefs(L"Edit")
-    {
-      // no code
-    }
-
-    void Edit::Prefs::Initialize()
-    {
-      Scrollable::Prefs::Initialize();
-
-      frame=OS::display->GetFrame(OS::Display::listboxFrameIndex);
-    }
-
     Config::Config(const std::wstring& name)
     : name(name),
       createBackup(false),remTrailSpace(false),
@@ -322,6 +307,8 @@ namespace Lum {
       vSize(0),
       showBlockCursor(false)
     {
+      SetBackground(OS::display->GetFill(OS::Display::listboxBackgroundFillIndex));
+
       SetCanFocus(true);
       RequestFocus();
       SetRequestsKeyboard(true);
@@ -330,8 +317,6 @@ namespace Lum {
 
       top=vAdjustment->GetTopModel();
       first=hAdjustment->GetTopModel();
-
-      SetPrefs(Lum::Edit::prefs);
     }
 
     Edit::~Edit()
@@ -1713,12 +1698,26 @@ namespace Lum {
     {
       Scrollable::Draw(x,y,w,h);
 
-      if (!Intersect(x,y,w,h)) {
+      if (!OIntersect(x,y,w,h)) {
         return;
       }
 
+      OS::DrawInfo *draw=GetDrawInfo();
+
+      if (background.Valid() && background->HasBorder()) {
+        draw->PushClipBegin(x,y,w,h);
+        draw->SubClipRegion(this->x,this->y,this->width,this->height);
+        draw->PushClipEnd();
+        DrawBackground(x,y,w,h);
+        draw->PopClip();
+      }
+
       /* --- */
 
+      if (!Intersect(x,y,w,h)) {
+        return;
+      }
+
       if (model.Valid()) {
         size_t start,end;
 
@@ -1732,8 +1731,6 @@ namespace Lum {
         Update();
       }
       else {
-        OS::DrawInfo *draw=GetDrawInfo();
-
         draw->PushForeground(colorSheme->styles[ColorSheme::normalStyle].bg);
         draw->FillRectangle(this->x,this->y,this->width,this->height);
         draw->PopForeground();
