@@ -29,25 +29,6 @@
 
 namespace Lum {
 
-  static Header::Prefs *prefs=new Header::Prefs();
-
-  Header::Prefs::Prefs()
-  : Object::Prefs(L"Header")
-  {
-    // no code
-  }
-
-  void Header::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    background=OS::display->GetFill(OS::Display::columnBackgroundFillIndex);
-    columnFrame=OS::display->GetFrame(OS::Display::columnFrameIndex);
-    columnLeftFrame=OS::display->GetFrame(OS::Display::columnLeftFrameIndex);
-    columnMiddleFrame=OS::display->GetFrame(OS::Display::columnMiddleFrameIndex);
-    columnRightFrame=OS::display->GetFrame(OS::Display::columnRightFrameIndex);
-  }
-
   class HeaderEntry : public Object
   {
   private:
@@ -57,24 +38,20 @@ namespace Lum {
     HeaderEntry(const std::wstring& label, size_t current, size_t max)
     : label(new Lum::Text(label))
     {
-      SetPrefs(Lum::prefs);
-
-      SetCanDrawMouseActive(true);
-
       if (max==1) {
-        SetFrame(dynamic_cast<Header::Prefs*>(prefs)->columnFrame);
+        SetBackground(OS::display->GetFill(OS::Display::columnBackgroundFillIndex));
       }
       else if (current==1) {
-        SetFrame(dynamic_cast<Header::Prefs*>(prefs)->columnLeftFrame);
+        SetBackground(OS::display->GetFill(OS::Display::columnLeftBackgroundFillIndex));
       }
       else if (current==max) {
-        SetFrame(dynamic_cast<Header::Prefs*>(prefs)->columnRightFrame);
+        SetBackground(OS::display->GetFill(OS::Display::columnRightBackgroundFillIndex));
       }
       else {
-        SetFrame(dynamic_cast<Header::Prefs*>(prefs)->columnMiddleFrame);
+        SetBackground(OS::display->GetFill(OS::Display::columnMiddleBackgroundFillIndex));
       }
 
-      SetBackground(dynamic_cast<Header::Prefs*>(prefs)->background);
+      SetRedrawOnMouseActive(true);
 
       this->label->SetFlex(true,true);
       this->label->SetParent(this);
@@ -98,10 +75,9 @@ namespace Lum {
       label->CalcSize();
 
       minWidth=1;
-      minHeight=label->GetOHeight()+frame->minHeight;
+      minHeight=label->GetOHeight();
 
-      width=label->GetOWidth()+frame->minWidth+
-            2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
+      width=label->GetOWidth()+2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
       height=minHeight;
 
       Object::CalcSize();
@@ -125,7 +101,7 @@ namespace Lum {
 
       Object::Draw(x,y,w,h);
 
-      if (!Intersect(x,y,w,h)) {
+      if (!OIntersect(x,y,w,h)) {
         draw->activated=false;
         return;
       }
@@ -148,7 +124,7 @@ namespace Lum {
   Header::Header()
   : model(NULL),adjustment(NULL)
   {
-    SetPrefs(Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::backgroundFillIndex));
   }
 
   Header::~Header()
@@ -193,9 +169,7 @@ namespace Lum {
 
     if (!model.Valid()) {
       width=1;
-      height=OS::display->GetFont()->height+
-             dynamic_cast<Prefs*>(prefs)->columnFrame->minHeight/*+
-             2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder)*/;
+      height=OS::display->GetFont()->height;
     }
     else {
       objects.resize(model->GetColumns());
@@ -231,7 +205,7 @@ namespace Lum {
         xPos=x;
       }
 
-      draw->PushClip(x,y,width,height);
+      draw->PushClip(GetOX(),GetOY(),GetOWidth(),GetOHeight());
 
       for (size_t count=0; count<objects.size(); count++) {
         if (count>=startColumn &&
@@ -256,8 +230,6 @@ namespace Lum {
         OS::display->GetFill(OS::Display::columnEndBackgroundFillIndex)->Draw(draw,
                                                                               xPos,y,x+width-xPos+1,height,
                                                                               xPos,y,x+width-xPos+1,height);
-        OS::display->GetFrame(OS::Display::columnEndFrameIndex)->Draw(draw,
-                                                                      xPos,y,x+width-xPos+1,height);
       }
 
       draw->PopClip();
@@ -284,7 +256,7 @@ namespace Lum {
   {
     Control::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
