@@ -21,17 +21,9 @@
 
 namespace Lum {
 
-  static Image::Prefs *prefs=new Image::Prefs(L"Image");
-
-  Image::Prefs::Prefs(const std::wstring& name)
-    : Control::Prefs(name)
-  {
-    // no code
-  }
-
   Image::Image()
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 
   Image::~Image()
@@ -51,9 +43,6 @@ namespace Lum {
     osImage=image;
 
     if (osImage.Valid()) {
-      if (osImage->GetDrawCap() & OS::Image::drawsActivated) {
-        SetCanDrawMouseActive(true);
-      }
 
       /*
       if (osImage->GetAlpha()) {
