@@ -23,11 +23,9 @@
 
 namespace Lum {
 
-  static ImageState::Prefs *prefs=new ::Lum::ImageState::Prefs(L"LED");
-
   LED::LED()
    : ImageState(OS::Theme::objLED,false)
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 }
