@@ -30,100 +30,14 @@
 
 namespace Lum {
 
-  class MenuStripPrefs : public List::Prefs
-  {
-  public:
-    MenuStripPrefs(const std::wstring& name)
-    : List::Prefs(name)
-    {
-      // no code
-    }
-
-    void Initialize()
-    {
-      List::Prefs::Initialize();
-
-      background=OS::display->GetFill(OS::Display::menuStripBackgroundFillIndex);
-      frame=OS::display->GetFrame(OS::Display::menuStripFrameIndex);
-    }
-  };
-
-  class PullDownMenuPrefs : public Object::Prefs
-  {
-  public:
-    PullDownMenuPrefs(const std::wstring& name)
-    : Object::Prefs(name)
-    {
-      // no code
-    }
-
-    void Initialize()
-    {
-      Object::Prefs::Initialize();
-
-      background=OS::display->GetFill(OS::Display::menuPulldownBackgroundFillIndex);
-      frame=OS::display->GetFrame(OS::Display::menuPulldownFrameIndex);
-    }
-  };
-
-  class MenuEntryPrefs : public Control::Prefs
-  {
-  public:
-    OS::ImageRef        arrow;      //! Image used for sub menues
-    OS::ImageRef        check;      //! Image used for boolean menues
-    OS::ImageRef        radio;      //! Image used for radio menues
-    OS::ImageRef        divider;    //! Image used as menu divider
-
-  public:
-    MenuEntryPrefs(const std::wstring& name)
-    : Control::Prefs(name)
-    {
-      // no code
-    }
-
-    void Initialize()
-    {
-      Control::Prefs::Initialize();
-
-      background=OS::display->GetFill(OS::Display::menuEntryBackgroundFillIndex);
-
-      arrow=OS::display->GetImage(OS::Display::menuSubImageIndex);
-      check=OS::display->GetImage(OS::Display::menuCheckImageIndex);
-      radio=OS::display->GetImage(OS::Display::menuRadioImageIndex);
-      divider=OS::display->GetImage(OS::Display::menuDividerImageIndex);
-    }
-  };
-
-  class MenuPrefs : public Object::Prefs
-  {
-  public:
-    MenuPrefs(const std::wstring& name)
-    : Object::Prefs(name)
-    {
-      // no code
-    }
-
-    void Initialize()
-    {
-      Object::Prefs::Initialize();
-
-      frame=OS::display->GetFrame(OS::Display::menuWindowFrameIndex);
-    }
-  };
-
-  static MenuStripPrefs    *menuStripPrefs=new MenuStripPrefs(L"MenuStrip");
-  static PullDownMenuPrefs *pullDownMenuPrefs=new PullDownMenuPrefs(L"PullDownMenu");
-  static MenuEntryPrefs    *menuEntryPrefs=new MenuEntryPrefs(L"MenuEntry");
-  static MenuPrefs         *menuPrefs=new MenuPrefs(L"Menu");
-
   /* ---------- Menustrip stuff ------------------*/
 
   MenuStrip::MenuStrip()
   : selection(NULL),stickyMode(false)
   {
-    SetFlex(true,false);
+    SetBackground(OS::display->GetFill(OS::Display::menuStripBackgroundFillIndex));
 
-    SetPrefs(menuStripPrefs);
+    SetFlex(true,false);
   }
 
   /**
@@ -338,12 +252,10 @@ namespace Lum {
     shortcutAction(new Model::Action),
     subMenu(NULL)
   {
-    SetPrefs(pullDownMenuPrefs);
+    SetBackground(OS::display->GetFill(OS::Display::menuPulldownBackgroundFillIndex));
 
     SetFlex(true,true);
 
-    SetCanDrawMouseActive(true);
-
     AttachModel(shortcutAction);
   }
 
@@ -425,7 +337,7 @@ namespace Lum {
 
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       draw->activated=false;
       return;
     }
@@ -469,7 +381,7 @@ namespace Lum {
     w1(0),w2(0),w3(0),w4(0),
     menuWindow(NULL)
   {
-    SetPrefs(menuEntryPrefs);
+    SetBackground(OS::display->GetFill(OS::Display::menuEntryBackgroundFillIndex));
 
     shortcutAlways=true;
 
@@ -692,7 +604,7 @@ namespace Lum {
   {
     MenuEntry::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -726,7 +638,7 @@ namespace Lum {
 
   void SeparatorItem::CalcSize()
   {
-    height=dynamic_cast<MenuEntryPrefs*>(prefs)->divider->GetHeight();
+    height=OS::display->GetImage(OS::Display::menuDividerImageIndex)->GetHeight();
     height+=2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
 
     MenuEntry::CalcSize();
@@ -736,13 +648,13 @@ namespace Lum {
   {
     MenuEntry::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
     /* --- */
 
-    OS::ImageRef divider=dynamic_cast<MenuEntryPrefs*>(prefs)->divider;
+    OS::ImageRef divider=OS::display->GetImage(OS::Display::menuDividerImageIndex);
     OS::DrawInfo *draw=GetDrawInfo();
 
     DrawBackground(x,y,w,h);
@@ -792,7 +704,7 @@ namespace Lum {
   {
     CalcLabelSize();
 
-    subImage=dynamic_cast<MenuEntryPrefs*>(prefs)->arrow;
+    subImage=OS::display->GetImage(OS::Display::menuSubImageIndex);
     w4=subImage->GetWidth();
 
     width=w1+w2+w3+w4;
@@ -805,7 +717,7 @@ namespace Lum {
   {
     MenuEntry::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -849,7 +761,7 @@ namespace Lum {
   {
     selectable=true;
 
-    image=dynamic_cast<MenuEntryPrefs*>(prefs)->check;
+    image=OS::display->GetImage(OS::Display::menuCheckImageIndex);
   }
 
   bool BoolItem::SetModel(Base::Model* model)
@@ -884,7 +796,7 @@ namespace Lum {
   {
     MenuEntry::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -927,7 +839,7 @@ namespace Lum {
   {
     selectable=true;
 
-    image=dynamic_cast<MenuEntryPrefs*>(prefs)->radio;
+    image=OS::display->GetImage(OS::Display::menuRadioImageIndex);
   }
 
   bool RadioItem::SetModel(Base::Model* model)
@@ -967,7 +879,7 @@ namespace Lum {
   {
     MenuEntry::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -1027,7 +939,7 @@ namespace Lum {
 
   MenuBox::MenuBox()
   {
-    SetPrefs(menuPrefs);
+    SetBackground(OS::display->GetFill(OS::Display::menuWindowBackgroundFillIndex));
   }
 
   void MenuBox::RegisterToParentWindow(OS::Window* parent)
@@ -1533,18 +1445,19 @@ namespace Lum {
 
     old=selected;
     if (entry!=old) {
-      if ((entry!=NULL) && !entry->IsSelectable()) {
-        entry=NULL;
+      if (entry!=NULL && !entry->IsSelectable()) {
+        selected=NULL;
+      }
+      else {
+        selected=entry;
       }
-
-      selected=entry;
 
       if (old!=NULL) {
         old->Redraw();
       }
 
-      if (entry!=NULL) {
-        entry->Redraw();
+      if (selected!=NULL) {
+        selected->Redraw();
       }
     }
   }
@@ -1674,7 +1587,7 @@ namespace Lum {
         if (menu!=NULL && menu->CursorIsIn()) {
           menu->Select(menu->GetSelected());
 
-          if (menu->selected!=NULL && menu->selected->IsSelectable()) {
+          if (menu->selected!=NULL) {
             EndAction();
             menu->selected->OnSelection();
           }
@@ -1759,9 +1672,10 @@ namespace Lum {
         EndAction();
         break;
       case OS::keyReturn:
-        if (selected!=NULL && selected->IsSelectable()) {
+        if (selected!=NULL) {
+          MenuEntry *tmp=selected; // EndAction my close the window and destroy variable "selected"
           EndAction();
-          selected->OnSelection();
+          tmp->OnSelection();
         }
         break;
       case OS::keyUp:
