@@ -281,12 +281,39 @@ namespace Lum {
           Notify();
         }
         else if (pos>top->Get()+visible->Get()-1) {
-          top->Set(std::max((size_t)1,pos-visible->Get()+1));
+          if (pos<visible->Get()) {
+            top->Set(1);
+          }
+          else {
+            top->Set(pos-visible->Get()+1);
+          }
           Notify();
         }
       }
     }
 
+    void Adjustment::CenterOn(size_t pos)
+    {
+      if (pos<=visible->Get()/2) {
+        ShowFirstPage();
+      }
+      else if (pos>=total->Get()-visible->Get()/2+1) {
+        ShowLastPage();
+      }
+      else {
+        SetTop(pos-visible->Get()/2);
+      }
+    }
+
+    void Adjustment::ShowFirstPage()
+    {
+      SetTop(1);
+    }
+    void Adjustment::ShowLastPage()
+    {
+      SetTop(total->Get()-visible->Get()+1);
+    }
+
     void Adjustment::SetStepSize(size_t stepSize)
     {
       this->stepSize=stepSize;
@@ -298,4 +325,4 @@ namespace Lum {
     }
 
   }
-}
+}
\ No newline at end of file
