@@ -40,7 +40,7 @@ namespace Lum {
       Display::Display()
       : scrWidth(0),scrHeight(0),workAreaWidth(0),workAreaHeight(0),
         multiClickTime(200),
-        appName(L""),prefs(NULL),
+        appName(L""),
         theme(NULL),
         keyboardHandler(NULL)
       {
@@ -132,33 +132,13 @@ namespace Lum {
         return args[pos];
       }
 
-      std::wstring Display::GetPrefsPath() const
+      std::wstring Display::GetThemePath() const
       {
         ::Lum::Base::Path path;
 
         path.SetNativeDir(::Lum::Base::Path::GetHome());
         path.AppendDir(L".illumination");
-
-        return path.GetPath();
-      }
-
-      std::wstring Display::GetPrefsName() const
-      {
-        ::Lum::Base::Path path;
-
-        path.SetNativeDir(GetPrefsPath());
-        path.SetBaseName(driver->GetDriverName()+L".xml");
-
-        return path.GetPath();
-      }
-
-      std::wstring Display::GetThemePath() const
-      {
-        ::Lum::Base::Path path;
-
-        path.SetNativeDir(GetPrefsPath());
         path.AppendDir(L"themes");
-        path.AppendDir(prefs->theme);
 
         return path.GetPath();
       }
