@@ -29,6 +29,312 @@ namespace Lum {
   namespace OS {
     namespace Base {
 
+      /**
+        Draw background using a plain color.
+      */
+      class FrameFill : public Fill
+      {
+      public:
+        enum Type {
+          none,
+          single3DIn,
+          single3DOut,
+          singleFrame, //! Simple black frame of 1 pixel size
+          double3DOut,
+          ridge,
+          button,      //! graphical button frame
+          box,         //! box frame
+          tabRider,    //! "normal" tab rider
+          label,       //! Draw focus frame only if draw->focused
+        };
+
+      private:
+        Type  type;
+        Color color;
+
+      public:
+        FrameFill(Type type, Color color);
+
+        void Draw(DrawInfo* draw,
+                  int xOff, int yOff, size_t width, size_t height,
+                  int x, int y, size_t w, size_t h);
+      };
+
+      FrameFill::FrameFill(Type type, Color color)
+      : type(type),
+        color(color)
+      {
+        switch (type) {
+        case none:
+          topBorder=0;
+          bottomBorder=0;
+          leftBorder=0;
+          rightBorder=0;
+          break;
+        case single3DIn:
+        case single3DOut:
+        case singleFrame:
+          topBorder=1;
+          bottomBorder=1;
+          leftBorder=1;
+          rightBorder=1;
+          break;
+        case double3DOut:
+        case ridge:
+          topBorder=2;
+          bottomBorder=2;
+          leftBorder=2;
+          rightBorder=2;
+          break;
+        case button:
+          topBorder=4;
+          bottomBorder=4;
+          leftBorder=4;
+          rightBorder=4;
+          break;
+        case box:
+          topBorder=2;
+          bottomBorder=2;
+          leftBorder=2;
+          rightBorder=2;
+          break;
+        case tabRider:
+          topBorder=2;
+          bottomBorder=0;
+          leftBorder=2;
+          rightBorder=2;
+          transparentBorder=true;
+          break;
+        case label:
+          topBorder=1;
+          bottomBorder=1;
+          leftBorder=1;
+          rightBorder=1;
+          transparentBorder=true;
+          break;
+        }
+      }
+
+      void FrameFill::Draw(OS::DrawInfo* draw,
+                           int xOff, int yOff, size_t width, size_t height,
+                           int x, int y, size_t w, size_t h)
+      {
+        Color shine,shadow,halfShadow,halfShine;
+        int   type;
+
+        x=xOff;
+        y=yOff;
+        w=width;
+        h=height;
+
+        draw->PushForeground(color);
+        draw->FillRectangle(x,y,w,h);
+        draw->PopForeground();
+
+        shine=dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor;
+        shadow=dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor;
+        halfShadow=dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor;
+        halfShine=dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShineColor;
+
+        type=this->type;
+
+        if (draw->selected) {
+          switch (type) {
+          case single3DOut:
+            type=single3DIn;
+            break;
+          default:
+            break;
+          }
+        }
+
+        switch (type) {
+        case double3DOut:
+          draw->PushForeground(shine);
+          draw->DrawLine(x,y+h-1,x,y+1);
+          draw->DrawLine(x,y,x+w-1,y);
+          draw->DrawLine(x+1,y+h-2,x+1,y+2);
+          draw->DrawLine(x+1,y+1,x+w-2,y+1);
+          draw->PopForeground();
+
+          draw->PushForeground(shadow);
+          draw->DrawLine(x+w-1,y+1,x+w-1,y+h-1);
+          draw->DrawLine(x+w-1,y+h-1,x,y+h-1);
+          draw->DrawLine(x+w-2,y+2,x+w-2,y+h-2);
+          draw->DrawLine(x+w-2,y+h-2,x+1,y+h-2);
+          draw->PopForeground();
+          break;
+
+        case single3DIn:
+        case single3DOut:
+          if (type==single3DIn) {
+            draw->PushForeground(shadow);
+          }
+          else {
+            draw->PushForeground(shine);
+          }
+          draw->DrawLine(x,y+h-1,x,y+1);
+          draw->DrawLine(x,y,x+w-1,y);
+          draw->PopForeground();
+
+          if (type==single3DIn) {
+            draw->PushForeground(shine);
+          }
+          else {
+            draw->PushForeground(shadow);
+          }
+          draw->DrawLine(x+w-1,y+1,x+w-1,y+h-1);
+          draw->DrawLine(x+w-1,y+h-1,x,y+h-1);
+          draw->PopForeground();
+          break;
+
+        case singleFrame:
+          draw->PushForeground(shadow);
+          draw->DrawRectangle(x,y,w,h);
+          draw->PopForeground();
+          break;
+
+        case ridge:
+          draw->PushForeground(shine);
+          draw->DrawLine(x,y,x+w-2,y);
+          draw->DrawLine(x+2,y+h-2,x+w-2,y+h-2);
+          draw->DrawLine(x,y+h-1,x,y);
+          draw->DrawLine(x+w-2,y+2,x+w-2,y+h-2);
+          draw->PopForeground();
+
+          draw->PushForeground(shadow);
+          draw->DrawLine(x+w-1,y,x+w-1,y+h-1);
+          draw->DrawLine(x+1,y+h-2,x+1,y+1);
+          draw->DrawLine(x+1,y+h-1,x+w-1,y+h-1);
+          draw->DrawLine(x+1,y+1,x+w-2,y+1);
+          draw->PopForeground();
+          break;
+
+        case button:
+          if (draw->selected) {
+            draw->PushForeground(OS::Display::blackColor);
+            draw->DrawRectangle(x,y,w,h);
+            draw->PopForeground();
+            draw->PushForeground(halfShadow);
+            draw->DrawRectangle(x+1,y+1,w-2,h-2);
+            draw->PopForeground();
+          }
+          else {
+            draw->PushForeground(shine);
+            draw->DrawLine(x,y+h-1,x,y+1);
+            draw->DrawLine(x,y,x+w-2,y);
+            draw->PopForeground();
+
+            draw->PushForeground(OS::Display::backgroundColor);
+            draw->DrawLine(x+1,y+h-2,x+1,y+2);
+            draw->DrawLine(x+1,y+1,x+w-3,y+1);
+            draw->PopForeground();
+
+            draw->PushForeground(shadow);
+            draw->DrawLine(x+w-1,y,x+w-1,y+h-1);
+            draw->DrawLine(x+w-1,y+h-1,x,y+h-1);
+            draw->PopForeground();
+
+            draw->PushForeground(halfShadow);
+            draw->DrawLine(x+w-2,y+1,x+w-2,y+h-2);
+            draw->DrawLine(x+w-2,y+h-2,x+1,y+h-2);
+            draw->PopForeground();
+          }
+          break;
+
+        case box:
+          draw->PushForeground(halfShadow);
+          draw->DrawLine(x,y+h-1,x,y+1);
+          draw->DrawLine(x,y,x+w-2,y);
+          draw->PopForeground();
+
+          draw->PushForeground(shadow);
+          draw->DrawLine(x+1,y+h-2,x+1,y+2);
+          draw->DrawLine(x+1,y+1,x+w-3,y+1);
+          draw->PopForeground();
+
+          draw->PushForeground(shine);
+          draw->DrawLine(x+w-1,y,x+w-1,y+h-1);
+          draw->DrawLine(x+w-1,y+h-1,x,y+h-1);
+          draw->PopForeground();
+
+          draw->PushForeground(OS::Display::backgroundColor);
+          draw->DrawLine(x+w-2,y+1,x+w-2,y+h-2);
+          draw->DrawLine(x+w-2,y+h-2,x+1,y+h-2);
+          draw->PopForeground();
+          break;
+
+        case tabRider:
+          // right
+          draw->PushForeground(shadow);
+          draw->DrawLine(x+w-1,y+3,x+w-1,y+h-1);
+          draw->DrawLine(x+w-2,y+1,x+w-2,y+h-1);
+          draw->PopForeground();
+
+          draw->PushForeground(shine);
+
+          // top
+          draw->DrawLine(x+3,y  ,x+w-4,y);
+          draw->DrawLine(x+1,y+1,x+w-3,y+1);
+
+          // left
+          draw->DrawLine(x  ,y+3,x    ,y+h-1);
+          draw->DrawLine(x+1,y+1,x+1  ,y+h-1);
+
+          draw->PopForeground();
+          break;
+        case label:
+          if (draw->focused) {
+            draw->PushForeground(OS::Display::textColor);
+            draw->PushDash("\002\002",2,OS::DrawInfo::fDash);
+            draw->DrawLine(x          ,y,      x+w-1,y);
+            draw->DrawLine(x+w-1,y,            x+w-1,y+h-1);
+            draw->DrawLine(x+w-1,y+h-1,x,            y+h-1);
+            draw->DrawLine(x          ,y+h-1,x,      y);
+            draw->PopDash();
+            draw->PopForeground();
+          }
+          break;
+        }
+      }
+
+      class SelectFill : public Fill
+      {
+      private:
+        Color colorA;
+        Color colorB;
+
+      public:
+        SelectFill(Color colorA, Color colorB);
+
+        void Draw(DrawInfo* draw,
+                  int xOff, int yOff, size_t width, size_t height,
+                  int x, int y, size_t w, size_t h);
+      };
+
+      SelectFill::SelectFill(Color colorA, Color colorB)
+      : colorA(colorA),
+        colorB(colorB)
+      {
+        // no code
+      }
+
+      void SelectFill::Draw(OS::DrawInfo* draw,
+                            int xOff, int yOff, size_t width, size_t height,
+                            int x, int y, size_t w, size_t h)
+      {
+        if (draw->selected) {
+          draw->PushForeground(colorB);
+        }
+        else {
+          draw->PushForeground(colorA);
+        }
+
+        draw->FillRectangle(x,y,w,h);
+
+        draw->PopForeground();
+      }
+
       Theme::Theme(OS::Display *display)
       : OS::Theme(display),
         display(display)
@@ -111,24 +417,28 @@ namespace Lum {
       {
       public:
         enum Type {
-          radio           =  0,
-          checkbox        =  1,
-          hSliderKnob     =  2,
-          vSliderKnob     =  3,
-          sliderUnfilled  =  4,
-          sliderFilled    =  5,
-          knob            =  6,
-          arrowUp         =  7,
-          arrowDown       =  8,
-          arrowLeft       =  9,
-          arrowRight      = 10,
-          hLine           = 11,
-          vLine           = 12,
-          combo           = 13,
-          comboButton     = 14,
-          led             = 15,
-          treeCross       = 16,
-          close           = 17
+          radio,
+          checkbox,
+          hSliderKnob,
+          vSliderKnob,
+          sliderUnfilled,
+          sliderFilled,
+          knob,
+          arrowUp,
+          arrowDown,
+          arrowLeft,
+          arrowRight,
+          scrollArrowUp,
+          scrollArrowDown,
+          scrollArrowLeft,
+          scrollArrowRight,
+          hLine,
+          vLine,
+          combo,
+          comboButton,
+          led,
+          treeCross,
+          close
         };
 
       private:
@@ -162,18 +472,14 @@ namespace Lum {
       {
       public:
         enum Type {
-          single3DIn   =  0,
-          single3DOut  =  1,
-          singleFrame  =  2, //! Simple black frame of 1 pixel size
-          double3DOut  =  3,
-          group3D      =  4,
-          ridge        =  5,
-          focus        =  6, //! A dotted-line focus frame
-          button       =  7, //! graphical button frame
-          box          =  8, //! box frame
-          tabRider     =  9, //! "normal" tab rider
-          tab          = 10, //! "Normal" frame for complete tab
-          label        = 11  //! Draw focus frame only if draaw->focused
+          single3DIn,
+          single3DOut,
+          singleFrame, //! Simple black frame of 1 pixel size
+          double3DOut,
+          group3D,
+          focus,       //! A dotted-line focus frame
+          box,         //! box frame
+          tab,         //! "Normal" frame for complete tab
         };
 
       public:
@@ -207,6 +513,10 @@ namespace Lum {
         case arrowDown:
         case arrowLeft:
         case arrowRight:
+        case scrollArrowUp:
+        case scrollArrowDown:
+        case scrollArrowLeft:
+        case scrollArrowRight:
           drawCap|=drawsDisabled;
           break;
         case hSliderKnob:
@@ -250,6 +560,13 @@ namespace Lum {
           width=3*unit/2;
           height=3*unit/2;
           break;
+        case scrollArrowLeft:
+        case scrollArrowRight:
+        case scrollArrowUp:
+        case scrollArrowDown:
+          width=3*unit/2+4;
+          height=3*unit/2+4;
+          break;
         case knob:
           width=2*unit;
           height=2*unit;
@@ -347,6 +664,11 @@ namespace Lum {
       {
         OS::DrawInfo::Point points[3];
         OS::FontRef         font=OS::display->GetFont();
+        Color               shine,shadow,halfShadow;
+
+        shine=dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor;
+        shadow=dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor;
+        halfShadow=dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor;
 
         switch (type) {
         case hSliderKnob:
@@ -478,6 +800,209 @@ namespace Lum {
           draw->PopForeground();
           break;
 
+        case scrollArrowLeft:
+          draw->PushForeground(OS::Display::backgroundColor);
+          draw->FillRectangle(x+2,y+2,width-4,height-4);
+          draw->PopForeground();
+
+          if (draw->selected) {
+            draw->PushForeground(OS::Display::blackColor);
+            draw->DrawRectangle(x,y,width,height);
+            draw->PopForeground();
+            draw->PushForeground(halfShadow);
+            draw->DrawRectangle(x+1,y+1,width-2,height-2);
+            draw->PopForeground();
+          }
+          else {
+            draw->PushForeground(shine);
+            draw->DrawLine(x,y+height-1,x,y+1);
+            draw->DrawLine(x,y,x+width-2,y);
+            draw->PopForeground();
+
+            draw->PushForeground(OS::Display::backgroundColor);
+            draw->DrawLine(x+1,y+height-2,x+1,y+2);
+            draw->DrawLine(x+1,y+1,x+width-3,y+1);
+            draw->PopForeground();
+
+            draw->PushForeground(shadow);
+            draw->DrawLine(x+width-1,y,x+width-1,y+height-1);
+            draw->DrawLine(x+width-1,y+height-1,x,y+height-1);
+            draw->PopForeground();
+
+            draw->PushForeground(halfShadow);
+            draw->DrawLine(x+width-2,y+1,x+width-2,y+height-2);
+            draw->DrawLine(x+width-2,y+height-2,x+1,y+height-2);
+            draw->PopForeground();
+          }
+
+          if (draw->disabled) {
+            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+          }
+          else {
+            draw->PushForeground(OS::Display::blackColor);
+          }
+          points[0].x=x+width/5;
+          points[0].y=y+height / 2;
+          points[1].x=x+width-1-width/5;
+          points[1].y=y+height/5;
+          points[2].x=x+width-1-width/5;
+          points[2].y=y+height-1-height/5;
+          draw->FillPolygon(points,3);
+          draw->PopForeground();
+          break;
+
+        case scrollArrowRight:
+          draw->PushForeground(OS::Display::backgroundColor);
+          draw->FillRectangle(x+2,y+2,width-4,height-4);
+          draw->PopForeground();
+
+          if (draw->selected) {
+            draw->PushForeground(OS::Display::blackColor);
+            draw->DrawRectangle(x,y,width,height);
+            draw->PopForeground();
+            draw->PushForeground(halfShadow);
+            draw->DrawRectangle(x+1,y+1,width-2,height-2);
+            draw->PopForeground();
+          }
+          else {
+            draw->PushForeground(shine);
+            draw->DrawLine(x,y+height-1,x,y+1);
+            draw->DrawLine(x,y,x+width-2,y);
+            draw->PopForeground();
+
+            draw->PushForeground(OS::Display::backgroundColor);
+            draw->DrawLine(x+1,y+height-2,x+1,y+2);
+            draw->DrawLine(x+1,y+1,x+width-3,y+1);
+            draw->PopForeground();
+
+            draw->PushForeground(shadow);
+            draw->DrawLine(x+width-1,y,x+width-1,y+height-1);
+            draw->DrawLine(x+width-1,y+height-1,x,y+height-1);
+            draw->PopForeground();
+
+            draw->PushForeground(halfShadow);
+            draw->DrawLine(x+width-2,y+1,x+width-2,y+height-2);
+            draw->DrawLine(x+width-2,y+height-2,x+1,y+height-2);
+            draw->PopForeground();
+          }
+
+          if (draw->disabled) {
+            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+          }
+          else {
+            draw->PushForeground(OS::Display::blackColor);
+          }
+          points[0].x=x+width-1-width/5;
+          points[0].y=y+height / 2;
+          points[1].x=x+width/5;
+          points[1].y=y+height/5;
+          points[2].x=x+width/5;
+          points[2].y=y+height-1-height/5;
+          draw->FillPolygon(points,3);
+          draw->PopForeground();
+          break;
+
+        case scrollArrowUp:
+          draw->PushForeground(OS::Display::backgroundColor);
+          draw->FillRectangle(x+2,y+2,width-4,height-4);
+          draw->PopForeground();
+
+          if (draw->selected) {
+            draw->PushForeground(OS::Display::blackColor);
+            draw->DrawRectangle(x,y,width,height);
+            draw->PopForeground();
+            draw->PushForeground(halfShadow);
+            draw->DrawRectangle(x+1,y+1,width-2,height-2);
+            draw->PopForeground();
+          }
+          else {
+            draw->PushForeground(shine);
+            draw->DrawLine(x,y+height-1,x,y+1);
+            draw->DrawLine(x,y,x+width-2,y);
+            draw->PopForeground();
+
+            draw->PushForeground(OS::Display::backgroundColor);
+            draw->DrawLine(x+1,y+height-2,x+1,y+2);
+            draw->DrawLine(x+1,y+1,x+width-3,y+1);
+            draw->PopForeground();
+
+            draw->PushForeground(shadow);
+            draw->DrawLine(x+width-1,y,x+width-1,y+height-1);
+            draw->DrawLine(x+width-1,y+height-1,x,y+height-1);
+            draw->PopForeground();
+
+            draw->PushForeground(halfShadow);
+            draw->DrawLine(x+width-2,y+1,x+width-2,y+height-2);
+            draw->DrawLine(x+width-2,y+height-2,x+1,y+height-2);
+            draw->PopForeground();
+          }
+
+          if (draw->disabled) {
+            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+          }
+          else {
+            draw->PushForeground(OS::Display::blackColor);
+          }
+          points[0].x=x+width / 2;
+          points[0].y=y+height/5;
+          points[1].x=x+width/5;
+          points[1].y=y+height-1-height/5;
+          points[2].x=x+width-1-width/5;
+          points[2].y=y+height-1-height/5;
+          draw->FillPolygon(points,3);
+          draw->PopForeground();
+          break;
+
+        case scrollArrowDown:
+          draw->PushForeground(OS::Display::backgroundColor);
+          draw->FillRectangle(x+2,y+2,width-4,height-4);
+          draw->PopForeground();
+
+          if (draw->selected) {
+            draw->PushForeground(OS::Display::blackColor);
+            draw->DrawRectangle(x,y,width,height);
+            draw->PopForeground();
+            draw->PushForeground(halfShadow);
+            draw->DrawRectangle(x+1,y+1,width-2,height-2);
+            draw->PopForeground();
+          }
+          else {
+            draw->PushForeground(shine);
+            draw->DrawLine(x,y+height-1,x,y+1);
+            draw->DrawLine(x,y,x+width-2,y);
+            draw->PopForeground();
+
+            draw->PushForeground(OS::Display::backgroundColor);
+            draw->DrawLine(x+1,y+height-2,x+1,y+2);
+            draw->DrawLine(x+1,y+1,x+width-3,y+1);
+            draw->PopForeground();
+
+            draw->PushForeground(shadow);
+            draw->DrawLine(x+width-1,y,x+width-1,y+height-1);
+            draw->DrawLine(x+width-1,y+height-1,x,y+height-1);
+            draw->PopForeground();
+
+            draw->PushForeground(halfShadow);
+            draw->DrawLine(x+width-2,y+1,x+width-2,y+height-2);
+            draw->DrawLine(x+width-2,y+height-2,x+1,y+height-2);
+            draw->PopForeground();
+          }
+
+          if (draw->disabled) {
+            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+          }
+          else {
+            draw->PushForeground(OS::Display::blackColor);
+          }
+          points[0].x=x+width/5;
+          points[0].y=y+height/5;
+          points[1].x=x+width-1-width/5;
+          points[1].y=y+height/5;
+          points[2].x=x+width / 2;
+          points[2].y=y+height-1-height/5;
+          draw->FillPolygon(points,3);
+          draw->PopForeground();
+          break;
         case hLine:
           DrawRectangle(draw,x,y+(height-2) / 2,width,2,true);
           break;
@@ -616,12 +1141,6 @@ namespace Lum {
           rightBorder=1;
           break;
         case double3DOut:
-        case ridge:
-          topBorder=2;
-          bottomBorder=2;
-          leftBorder=2;
-          rightBorder=2;
-          break;
         case group3D:
           if (HasGap()) {
             topBorder=std::max((size_t)2,gh);
@@ -639,38 +1158,18 @@ namespace Lum {
           leftBorder=1;
           rightBorder=1;
           break;
-        case button:
-          topBorder=2;
-          bottomBorder=2;
-          leftBorder=2;
-          rightBorder=2;
-          break;
         case box:
           topBorder=2;
           bottomBorder=2;
           leftBorder=2;
           rightBorder=2;
           break;
-        case tabRider:
-          topBorder=2;
-          bottomBorder=0;
-          leftBorder=2;
-          rightBorder=2;
-          alpha=true;
-          break;
         case tab:
           topBorder=2;
           bottomBorder=2;
           leftBorder=2;
           rightBorder=2;
           break;
-        case label:
-          topBorder=1;
-          bottomBorder=1;
-          leftBorder=1;
-          rightBorder=1;
-          alpha=true;
-          break;
         }
 
         minWidth=leftBorder+rightBorder;
@@ -691,15 +1190,12 @@ namespace Lum {
       {
         Color shine,shadow,halfShadow,halfShine;
         int   top,type;
-        bool  set;
 
         shine=dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor;
         shadow=dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor;
         halfShadow=dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor;
         halfShine=dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShineColor;
 
-        set=false;
-
         type=this->type;
 
         if (draw->selected) {
@@ -795,22 +1291,6 @@ namespace Lum {
           draw->PopForeground();
           break;
 
-        case ridge:
-          draw->PushForeground(shine);
-          draw->DrawLine(x,y,x+w-2,y);
-          draw->DrawLine(x+2,y+h-2,x+w-2,y+h-2);
-          draw->DrawLine(x,y+h-1,x,y);
-          draw->DrawLine(x+w-2,y+2,x+w-2,y+h-2);
-          draw->PopForeground();
-
-          draw->PushForeground(shadow);
-          draw->DrawLine(x+w-1,y,x+w-1,y+h-1);
-          draw->DrawLine(x+1,y+h-2,x+1,y+1);
-          draw->DrawLine(x+1,y+h-1,x+w-1,y+h-1);
-          draw->DrawLine(x+1,y+1,x+w-2,y+1);
-          draw->PopForeground();
-          break;
-
         case focus:
           draw->PushForeground(OS::Display::textColor);
           draw->PushDash("\002\002",2,OS::DrawInfo::fDash);
@@ -822,38 +1302,6 @@ namespace Lum {
           draw->PopForeground();
           break;
 
-        case button:
-          if (draw->selected) {
-            draw->PushForeground(OS::Display::blackColor);
-            draw->DrawRectangle(x,y,w,h);
-            draw->PopForeground();
-            draw->PushForeground(halfShadow);
-            draw->DrawRectangle(x+1,y+1,w-2,h-2);
-            draw->PopForeground();
-          }
-          else {
-            draw->PushForeground(shine);
-            draw->DrawLine(x,y+h-1,x,y+1);
-            draw->DrawLine(x,y,x+w-2,y);
-            draw->PopForeground();
-
-            draw->PushForeground(OS::Display::backgroundColor);
-            draw->DrawLine(x+1,y+h-2,x+1,y+2);
-            draw->DrawLine(x+1,y+1,x+w-3,y+1);
-            draw->PopForeground();
-
-            draw->PushForeground(shadow);
-            draw->DrawLine(x+w-1,y,x+w-1,y+h-1);
-            draw->DrawLine(x+w-1,y+h-1,x,y+h-1);
-            draw->PopForeground();
-
-            draw->PushForeground(halfShadow);
-            draw->DrawLine(x+w-2,y+1,x+w-2,y+h-2);
-            draw->DrawLine(x+w-2,y+h-2,x+1,y+h-2);
-            draw->PopForeground();
-          }
-          break;
-
         case box:
           draw->PushForeground(halfShadow);
           draw->DrawLine(x,y+h-1,x,y+1);
@@ -876,27 +1324,6 @@ namespace Lum {
           draw->PopForeground();
           break;
 
-        case tabRider:
-          // right
-          draw->PushForeground(shadow);
-          draw->DrawLine(x+w-1,y+3,x+w-1,y+h-1);
-          draw->DrawLine(x+w-2,y+1,x+w-2,y+h-1);
-          draw->PopForeground();
-
-          draw->PushForeground(shine);
-
-          // top
-          draw->DrawLine(x+3,y  ,x+w-4,y);
-          draw->DrawLine(x+1,y+1,x+w-3,y+1);
-
-          // left
-          draw->DrawLine(x  ,y+3,x    ,y+h-1);
-          draw->DrawLine(x+1,y+1,x+1  ,y+h-1);
-
-          draw->PopForeground();
-
-          break;
-
         case tab:
           draw->PushForeground(shadow);
 
@@ -939,18 +1366,6 @@ namespace Lum {
           draw->PopForeground();
           break;
 
-        case label:
-          if (draw->focused) {
-            draw->PushForeground(OS::Display::textColor);
-            draw->PushDash("\002\002",2,OS::DrawInfo::fDash);
-            draw->DrawLine(x          ,y,      x+w-1,y);
-            draw->DrawLine(x+w-1,y,            x+w-1,y+h-1);
-            draw->DrawLine(x+w-1,y+h-1,x,            y+h-1);
-            draw->DrawLine(x          ,y+h-1,x,      y);
-            draw->PopDash();
-            draw->PopForeground();
-          }
-          break;
         }
       }
 
@@ -1028,7 +1443,7 @@ namespace Lum {
           fillNames[Display::tableBackground2FillIndex]=fillNames[Display::backgroundFillIndex];
           fillNames[Display::hprogressFillIndex]="black";
           fillNames[Display::vprogressFillIndex]="black";
-          fillNames[Display::helpBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+          fillNames[Display::tooltipWindowBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         }
         else if (display->GetColorMode()==Display::colorModeGreyScale) {
           fillNames[Display::backgroundFillIndex]="grey70";
@@ -1036,7 +1451,7 @@ namespace Lum {
           fillNames[Display::tableBackground2FillIndex]="grey95";
           fillNames[Display::hprogressFillIndex]="grey60";
           fillNames[Display::vprogressFillIndex]="grey60";
-          fillNames[Display::helpBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+          fillNames[Display::tooltipWindowBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         }
         else {
           fillNames[Display::backgroundFillIndex]="grey70";
@@ -1044,7 +1459,7 @@ namespace Lum {
           fillNames[Display::tableBackground2FillIndex]="grey95";
           fillNames[Display::hprogressFillIndex]="royal blue";
           fillNames[Display::vprogressFillIndex]="royal blue";
-          fillNames[Display::helpBackgroundFillIndex]="light yellow";
+          fillNames[Display::tooltipWindowBackgroundFillIndex]="light yellow";
         }
 
         fillNames[Display::buttonBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
@@ -1054,23 +1469,35 @@ namespace Lum {
         fillNames[Display::toolbarButtonBackgroundFillIndex]=fillNames[Display::buttonBackgroundFillIndex];
         fillNames[Display::scrollButtonBackgroundFillIndex]=fillNames[Display::buttonBackgroundFillIndex];
         fillNames[Display::comboBackgroundFillIndex]=fillNames[Display::buttonBackgroundFillIndex];
+        fillNames[Display::editComboBackgroundFillIndex]=fillNames[Display::buttonBackgroundFillIndex];
         fillNames[Display::entryBackgroundFillIndex]=fillNames[Display::tableBackgroundFillIndex];
         fillNames[Display::hprogressBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
-        fillNames[Display::hprogressFillIndex]=fillNames[Display::hprogressFillIndex];
         fillNames[Display::vprogressBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
-        fillNames[Display::vprogressFillIndex]=fillNames[Display::vprogressFillIndex];
         fillNames[Display::hknobBoxFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::vknobBoxFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::tabBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::tabRiderBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::columnBackgroundFillIndex]=fillNames[Display::buttonBackgroundFillIndex];
+        fillNames[Display::columnLeftBackgroundFillIndex]=fillNames[Display::columnBackgroundFillIndex];
+        fillNames[Display::columnRightBackgroundFillIndex]=fillNames[Display::columnBackgroundFillIndex];
+        fillNames[Display::columnMiddleBackgroundFillIndex]=fillNames[Display::columnBackgroundFillIndex];
         fillNames[Display::columnEndBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::menuStripBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::menuPulldownBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::menuEntryBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::menuWindowBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::popupWindowBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::dialogWindowBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::graphBackgroundFillIndex]="white";
         fillNames[Display::toolbarBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::labelBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::listboxBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::scrolledBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::hscrollBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::vscrollBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::boxedBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::plateBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::statusbarBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
 
         for (size_t i=0; i<Display::fillCount; i++) {
           display->AllocateNamedColor(fillNames[i],fillColors[i]);
@@ -1080,45 +1507,39 @@ namespace Lum {
           fill[i]=new PlainFill(fillColors[i]);
         }
 
-        frame[Display::buttonFrameIndex]=new InternalFrame(InternalFrame::button);
-        frame[Display::positiveButtonFrameIndex]=new InternalFrame(InternalFrame::button);
-        frame[Display::negativeButtonFrameIndex]=new InternalFrame(InternalFrame::button);
-        frame[Display::defaultButtonFrameIndex]=new InternalFrame(InternalFrame::button);
-        frame[Display::toolbarButtonFrameIndex]=new InternalFrame(InternalFrame::button);
-        frame[Display::scrollButtonFrameIndex]=frame[Display::buttonFrameIndex];
-        frame[Display::editFrameIndex]=new InternalFrame(InternalFrame::box);
-        frame[Display::hprogressFrameIndex]=new InternalFrame(InternalFrame::box);
-        frame[Display::vprogressFrameIndex]=new InternalFrame(InternalFrame::box);
-        frame[Display::hknobBoxFrameIndex]=emptyFrame;
-        frame[Display::vknobBoxFrameIndex]=emptyFrame;
-        frame[Display::hscrollFrameIndex]=emptyFrame;
-        frame[Display::vscrollFrameIndex]=emptyFrame;
+        fill[Display::tableBackgroundFillIndex]=new SelectFill(fillColors[Display::tableBackgroundFillIndex],color[Display::fillColor]);
+        fill[Display::tableBackground2FillIndex]=new SelectFill(fillColors[Display::tableBackground2FillIndex],color[Display::fillColor]);
+        fill[Display::entryBackgroundFillIndex]=new SelectFill(fillColors[Display::entryBackgroundFillIndex],color[Display::fillColor]);
+
+        fill[Display::buttonBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::buttonBackgroundFillIndex]);
+        fill[Display::positiveButtonBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::positiveButtonBackgroundFillIndex]);
+        fill[Display::negativeButtonBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::negativeButtonBackgroundFillIndex]);
+        fill[Display::defaultButtonBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::defaultButtonBackgroundFillIndex]);
+        fill[Display::toolbarButtonBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::toolbarButtonBackgroundFillIndex]);
+        fill[Display::hprogressBackgroundFillIndex]=new FrameFill(FrameFill::box,fillColors[Display::hprogressBackgroundFillIndex]);
+        fill[Display::vprogressBackgroundFillIndex]=new FrameFill(FrameFill::box,fillColors[Display::vprogressBackgroundFillIndex]);
+        fill[Display::comboBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::comboBackgroundFillIndex]);
+        fill[Display::editComboBackgroundFillIndex]=new FrameFill(FrameFill::box,fillColors[Display::editComboBackgroundFillIndex]);
+        fill[Display::tabRiderBackgroundFillIndex]=new FrameFill(FrameFill::tabRider,fillColors[Display::tabRiderBackgroundFillIndex]);
+        fill[Display::columnBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::columnBackgroundFillIndex]);
+        fill[Display::columnLeftBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::columnLeftBackgroundFillIndex]);
+        fill[Display::columnMiddleBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::columnMiddleBackgroundFillIndex]);
+        fill[Display::columnRightBackgroundFillIndex]=new FrameFill(FrameFill::button,fillColors[Display::columnRightBackgroundFillIndex]);
+        fill[Display::menuWindowBackgroundFillIndex]=new FrameFill(FrameFill::double3DOut,fillColors[Display::menuWindowBackgroundFillIndex]);
+        fill[Display::popupWindowBackgroundFillIndex]=new FrameFill(FrameFill::double3DOut,fillColors[Display::popupWindowBackgroundFillIndex]);
+        fill[Display::tooltipWindowBackgroundFillIndex]=new FrameFill(FrameFill::singleFrame,fillColors[Display::tooltipWindowBackgroundFillIndex]);
+        fill[Display::labelBackgroundFillIndex]=new FrameFill(FrameFill::label,fillColors[Display::labelBackgroundFillIndex]);
+        fill[Display::scrolledBackgroundFillIndex]=new FrameFill(FrameFill::box,fillColors[Display::scrolledBackgroundFillIndex]);
+        fill[Display::boxedBackgroundFillIndex]=new FrameFill(FrameFill::box,fillColors[Display::boxedBackgroundFillIndex]);
+        fill[Display::plateBackgroundFillIndex]=new FrameFill(FrameFill::singleFrame,fillColors[Display::plateBackgroundFillIndex]);
+
         frame[Display::tabFrameIndex]=new InternalFrame(InternalFrame::tab);
-        frame[Display::tabRiderFrameIndex]=new InternalFrame(InternalFrame::tabRider);
-        frame[Display::listboxFrameIndex]=emptyFrame;
-        frame[Display::scrolledFrameIndex]=new InternalFrame(InternalFrame::box);
-        frame[Display::columnFrameIndex]=frame[Display::buttonFrameIndex];
-        frame[Display::columnLeftFrameIndex]=frame[Display::columnFrameIndex];
-        frame[Display::columnMiddleFrameIndex]=frame[Display::columnFrameIndex];
-        frame[Display::columnRightFrameIndex]=frame[Display::columnFrameIndex];
-        frame[Display::columnEndFrameIndex]=emptyFrame;
-        frame[Display::comboFrameIndex]=frame[Display::buttonFrameIndex];
-        frame[Display::editComboFrameIndex]=new InternalFrame(InternalFrame::box);
-        frame[Display::mainWindowFrameIndex]=emptyFrame;
-        frame[Display::menuWindowFrameIndex]=new InternalFrame(InternalFrame::double3DOut);
-        frame[Display::popupWindowFrameIndex]=new InternalFrame(InternalFrame::double3DOut);
-        frame[Display::tooltipWindowFrameIndex]=new InternalFrame(InternalFrame::singleFrame);
         frame[Display::hscaleFrameIndex]=new InternalFrame(InternalFrame::box);
         frame[Display::vscaleFrameIndex]=new InternalFrame(InternalFrame::box);
         frame[Display::focusFrameIndex]=new InternalFrame(InternalFrame::focus);
-        frame[Display::statusbarFrameIndex]=emptyFrame;
         frame[Display::statuscellFrameIndex]=new InternalFrame(InternalFrame::single3DIn);
-        frame[Display::plateFrameIndex]=new InternalFrame(InternalFrame::singleFrame);
         frame[Display::valuebarFrameIndex]=new InternalFrame(InternalFrame::single3DOut);
         frame[Display::groupFrameIndex]=new InternalFrame(InternalFrame::group3D);
-        frame[Display::menuStripFrameIndex]=emptyFrame;
-        frame[Display::menuPulldownFrameIndex]=emptyFrame;
-        frame[Display::labelFrameIndex]=new InternalFrame(InternalFrame::label);
 
         image[Display::hknobImageIndex]=new InternalImage(InternalImage::knob);
         image[Display::vknobImageIndex]=new InternalImage(InternalImage::knob);
@@ -1126,10 +1547,10 @@ namespace Lum {
         image[Display::arrowRightImageIndex]=new InternalImage(InternalImage::arrowRight);
         image[Display::arrowUpImageIndex]=new InternalImage(InternalImage::arrowUp);
         image[Display::arrowDownImageIndex]=new InternalImage(InternalImage::arrowDown);
-        image[Display::arrowScrollLeftImageIndex]=image[Display::arrowLeftImageIndex];
-        image[Display::arrowScrollRightImageIndex]=image[Display::arrowRightImageIndex];
-        image[Display::arrowScrollUpImageIndex]=image[Display::arrowUpImageIndex];
-        image[Display::arrowScrollDownImageIndex]=image[Display::arrowDownImageIndex];
+        image[Display::scrollLeftImageIndex]=new InternalImage(InternalImage::scrollArrowLeft);
+        image[Display::scrollRightImageIndex]=new InternalImage(InternalImage::scrollArrowRight);
+        image[Display::scrollUpImageIndex]=new InternalImage(InternalImage::scrollArrowUp);
+        image[Display::scrollDownImageIndex]=new InternalImage(InternalImage::scrollArrowDown);
         image[Display::comboImageIndex]=new InternalImage(InternalImage::combo);
         image[Display::comboEditButtonImageIndex]=new InternalImage(InternalImage::comboButton);
         image[Display::comboDividerImageIndex]=new InternalImage(InternalImage::vLine);
@@ -1229,7 +1650,7 @@ namespace Lum {
           return true;
           break;
         }
-        
+
         assert(false);
       }
 
