@@ -231,9 +231,6 @@ namespace Lum {
 
         EvaluateDisplaySize();
 
-        Lum::Prefs::LoadConfig(GetPrefsName());
-        Lum::Prefs::ReadDisplayConfig();
-
         for (int c=1; c<COLOR_PAIRS; c++) {
           if (init_pair(c,c%COLORS,c/COLORS)==ERR) {
             std::cerr << c << " " << c%COLORS << " " << c/COLORS << std::endl;
@@ -263,10 +260,6 @@ namespace Lum {
 
         multiClickTime=200;
 
-        Lum::Prefs::InitializePrefs(prefs);
-        Lum::Prefs::ReadOthersConfig();
-        Lum::Prefs::FreeData();
-
         return true;
       }
 
@@ -276,8 +269,6 @@ namespace Lum {
 
         OS::Base::Display::Close();
 
-        Lum::Prefs::FreePrefs();
-
         if (selectObject!=NULL) {
           CancelSelection();
         }
@@ -355,7 +346,6 @@ namespace Lum {
       {
         if (!content.empty()) {
           clipboard=content;
-          //XSetSelectionOwner(display,atoms[clipboardAtom],appWindow,CurrentTime);
           return true;
         }
         else {
@@ -375,12 +365,15 @@ namespace Lum {
       void Display::ClearClipboard()
       {
         if (!clipboard.empty()) {
-          //selClearPend=true;
-          //XSetSelectionOwner(display,atoms[clipboardAtom],None,CurrentTime);
           clipboard=L"";
         }
       }
 
+      bool Display::HasClipboard() const
+      {
+        return !clipboard.empty();
+      }
+
       void Display::PutBackEvent(OS::Event* /*event*/,
                                  OS::Window* /*destWin*/)
       {
