@@ -33,16 +33,18 @@ namespace Lum {
         case Display::arrowRightImageIndex:
         case Display::arrowUpImageIndex:
         case Display::arrowDownImageIndex:
-        case Display::arrowScrollLeftImageIndex:
-        case Display::arrowScrollRightImageIndex:
-        case Display::arrowScrollUpImageIndex:
-        case Display::arrowScrollDownImageIndex:
+        case Display::scrollLeftImageIndex:
+        case Display::scrollRightImageIndex:
+        case Display::scrollUpImageIndex:
+        case Display::scrollDownImageIndex:
         case Display::comboImageIndex:
         case Display::treeExpanderImageIndex:
         case Display::hscaleKnobImageIndex:
         case Display::vscaleKnobImageIndex:
         case Display::closeImageIndex:
         case Display::menuSubImageIndex:
+        case Display::hpaneHandleImageIndex:
+        case Display::vpaneHandleImageIndex:
           width=1;
           height=1;
           break;
@@ -117,6 +119,8 @@ namespace Lum {
               break;
             case Display::hknobImageIndex:
             case Display::vknobImageIndex:
+            case Display::hpaneHandleImageIndex:
+            case Display::vpaneHandleImageIndex:
               draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
               draw->FillRectangle(i,j,1,1);
               draw->PopForeground();
@@ -125,26 +129,26 @@ namespace Lum {
               draw->PopForeground();
               break;
             case Display::arrowLeftImageIndex:
-            case Display::arrowScrollLeftImageIndex:
+            case Display::scrollLeftImageIndex:
               draw->PushForeground(Display::textColor);
               draw->DrawString(i,j,L"<");
               draw->PopForeground();
               break;
             case Display::arrowRightImageIndex:
-            case Display::arrowScrollRightImageIndex:
+            case Display::scrollRightImageIndex:
             case Display::menuSubImageIndex:
               draw->PushForeground(Display::textColor);
               draw->DrawString(i,j,L">");
               draw->PopForeground();
               break;
             case Display::arrowUpImageIndex:
-            case Display::arrowScrollUpImageIndex:
+            case Display::scrollUpImageIndex:
               draw->PushForeground(Display::textColor);
               draw->DrawString(i,j,L"^");
               draw->PopForeground();
               break;
             case Display::arrowDownImageIndex:
-            case Display::arrowScrollDownImageIndex:
+            case Display::scrollDownImageIndex:
             case Display::comboImageIndex:
               draw->PushForeground(Display::textColor);
               draw->DrawString(i,j,L"v");
@@ -214,37 +218,67 @@ namespace Lum {
       TextFill::TextFill(Display::FillIndex fill)
       : fill(fill)
       {
-        // no code
+        switch ( fill) {
+        case Display::buttonBackgroundFillIndex:
+        case Display::defaultButtonBackgroundFillIndex:
+        case Display::positiveButtonBackgroundFillIndex:
+        case Display::negativeButtonBackgroundFillIndex:
+        case Display::toolbarButtonBackgroundFillIndex:
+        case Display::entryBackgroundFillIndex:
+          leftBorder=1;
+          rightBorder=1;
+          topBorder=0;
+          bottomBorder=0;
+          break;
+        case Display::hprogressBackgroundFillIndex:
+        case Display::vprogressBackgroundFillIndex:
+        case Display::scrolledBackgroundFillIndex:
+        case Display::boxedBackgroundFillIndex:
+        case Display::menuWindowBackgroundFillIndex:
+        case Display::popupWindowBackgroundFillIndex:
+          leftBorder=1;
+          rightBorder=1;
+          topBorder=1;
+          bottomBorder=1;
+          break;
+        case Display::statusbarBackgroundFillIndex:
+          leftBorder=0;
+          rightBorder=0;
+          topBorder=1;
+          bottomBorder=0;
+          break;
+        case Display::menuPulldownBackgroundFillIndex:
+          leftBorder=0;
+          rightBorder=1;
+          topBorder=0;
+          bottomBorder=0;
+          break;
+        case Display::tabRiderBackgroundFillIndex:
+          leftBorder=1;
+          rightBorder=leftBorder;
+          topBorder=1;
+          bottomBorder=0;
+          break;
+        default:
+          leftBorder=0;
+          rightBorder=0;
+          topBorder=0;
+          bottomBorder=0;
+        }
       }
 
       void TextFill::Draw(OS::DrawInfo* draw,
-                         int /*xOff*/, int /*yOff*/, size_t /*width*/, size_t /*height*/,
+                         int xOff, int yOff, size_t width, size_t height,
                          int x, int y, size_t w, size_t h)
       {
+        Color backgroundColor=OS::display->GetColor(Display::backgroundColor);
+
         switch (fill) {
         case Display::backgroundFillIndex:
           draw->PushForeground(Display::backgroundColor);
           draw->FillRectangle(x,y,w,h);
           draw->PopForeground();
           break;
-        case Display::buttonBackgroundFillIndex:
-        case Display::defaultButtonBackgroundFillIndex:
-        case Display::toolbarButtonBackgroundFillIndex:
-        case Display::scrollButtonBackgroundFillIndex:
-          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          draw->FillRectangle(x,y,w,h);
-          draw->PopForeground();
-          break;
-        case Display::positiveButtonBackgroundFillIndex:
-          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->positiveButtonBackgroundColor);
-          draw->FillRectangle(x,y,w,h);
-          draw->PopForeground();
-          break;
-        case Display::negativeButtonBackgroundFillIndex:
-          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->negativeButtonBackgroundColor);
-          draw->FillRectangle(x,y,w,h);
-          draw->PopForeground();
-          break;
         case Display::tableBackgroundFillIndex:
         case Display::tableBackground2FillIndex:
           if (draw->selected) {
@@ -256,18 +290,174 @@ namespace Lum {
           draw->FillRectangle(x,y,w,h);
           draw->PopForeground();
           break;
-        case Display::helpBackgroundFillIndex:
+        case Display::buttonBackgroundFillIndex:
+        case Display::defaultButtonBackgroundFillIndex:
+        case Display::toolbarButtonBackgroundFillIndex:
+          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff,i,L"[");
+          }
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff+width-1,i,L"]");
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
+        case Display::positiveButtonBackgroundFillIndex:
+          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->positiveButtonBackgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff,i,L"<");
+          }
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff+width-1,i,L">");
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
+        case Display::negativeButtonBackgroundFillIndex:
+          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->negativeButtonBackgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff,i,L"[");
+          }
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff+width-1,i,L"]");
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
+        case Display::scrollButtonBackgroundFillIndex:
+          draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+          break;
+          /* combo */
+          /* editCombo */
+        case Display::entryBackgroundFillIndex:
+          if (draw->selected) {
+            draw->PushForeground(Display::fillColor);
+          }
+          else {
+            draw->PushForeground(dynamic_cast<Theme*>(OS::display->GetTheme())->tableBackgroundColor);
+          }
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff,i,L"[");
+          }
+
+          for (size_t i=yOff; i<yOff+(size_t)height; ++i) {
+            draw->DrawString(xOff+width-1,i,L"]");
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
         case Display::menuStripBackgroundFillIndex:
           draw->PushForeground(Display::backgroundColor);
           draw->FillRectangle(x,y,w,h);
           draw->PopForeground();
           break;
+
+        case Display::hprogressBackgroundFillIndex:
+        case Display::vprogressBackgroundFillIndex:
+          draw->PushForeground(Display::backgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          draw->DrawFillString(xOff,yOff,L"\x250c",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff,L"\x2510",backgroundColor);
+          draw->DrawFillString(xOff,yOff+height-1,L"\x2514",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff+height-1,L"\x2518",backgroundColor);
+
+          // top
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff,L"\x2500",backgroundColor);
+          }
+
+          // left
+          for (int i=yOff+1; i<=yOff+(int)height-2; i++) {
+            draw->DrawFillString(xOff,i,L"\x2502",backgroundColor);
+          }
+
+          // right
+          for (int i=yOff+1; i<=yOff+(int)height-2; i++) {
+            draw->DrawFillString(xOff+width-1,i,L"\x2502",backgroundColor);
+          }
+
+          // bottom
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff+height-1,L"\x2500",backgroundColor);
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
         case Display::hprogressFillIndex:
         case Display::vprogressFillIndex:
           draw->PushForeground(Display::fillColor);
           draw->FillRectangle(x,y,w,h);
           draw->PopForeground();
           break;
+        case Display::tabRiderBackgroundFillIndex:
+          draw->PushForeground(Display::backgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          draw->DrawFillString(xOff,yOff,L"\x250c",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff,L"\x2510",backgroundColor);
+
+          // top
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff,L"\x2500",backgroundColor);
+          }
+
+          // left
+          for (int i=yOff+1; i<=yOff+(int)height-1; i++) {
+            draw->DrawFillString(xOff,i,L"\x2502",backgroundColor);
+          }
+
+          // right
+          for (int i=yOff+1; i<=yOff+(int)height-1; i++) {
+            draw->DrawFillString(xOff+width-1,i,L"\x2502",backgroundColor);
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
         case Display::menuPulldownBackgroundFillIndex:
           if (draw->selected) {
             draw->PushForeground(Display::fillColor);
@@ -288,6 +478,43 @@ namespace Lum {
           draw->FillRectangle(x,y,w,h);
           draw->PopForeground();
           break;
+        case Display::menuWindowBackgroundFillIndex:
+        case Display::popupWindowBackgroundFillIndex:
+          draw->PushForeground(Display::backgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          draw->DrawFillString(xOff,yOff,L"\x250c",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff,L"\x2510",backgroundColor);
+          draw->DrawFillString(xOff,yOff+height-1,L"\x2514",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff+height-1,L"\x2518",backgroundColor);
+
+          // top
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff,L"\x2500",backgroundColor);
+          }
+
+          // left
+          for (int i=yOff+1; i<=yOff+(int)height-2; i++) {
+            draw->DrawFillString(xOff,i,L"\x2502",backgroundColor);
+          }
+
+          // right
+          for (int i=yOff+1; i<=yOff+(int)height-2; i++) {
+            draw->DrawFillString(xOff+width-1,i,L"\x2502",backgroundColor);
+          }
+
+          // bottom
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff+height-1,L"\x2500",backgroundColor);
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
         case Display::graphBackgroundFillIndex:
           draw->PushForeground(Display::backgroundColor);
           draw->FillRectangle(x,y,w,h);
@@ -298,6 +525,64 @@ namespace Lum {
           draw->FillRectangle(x,y,w,h);
           draw->PopForeground();
           break;
+        case Display::listboxBackgroundFillIndex:
+          draw->PushForeground(Display::backgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+          break;
+        case Display::scrolledBackgroundFillIndex:
+        case Display::boxedBackgroundFillIndex:
+        case Display::plateBackgroundFillIndex:
+          draw->PushForeground(Display::backgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          draw->DrawFillString(xOff,yOff,L"\x250c",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff,L"\x2510",backgroundColor);
+          draw->DrawFillString(xOff,yOff+height-1,L"\x2514",backgroundColor);
+          draw->DrawFillString(xOff+width-1,yOff+height-1,L"\x2518",backgroundColor);
+
+          // top
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff,L"\x2500",backgroundColor);
+          }
+
+          // left
+          for (int i=yOff+1; i<=yOff+(int)height-2; i++) {
+            draw->DrawFillString(xOff,i,L"\x2502",backgroundColor);
+          }
+
+          // right
+          for (int i=yOff+1; i<=yOff+(int)height-2; i++) {
+            draw->DrawFillString(xOff+width-1,i,L"\x2502",backgroundColor);
+          }
+
+          // bottom
+          for (int i=xOff+1; i<=xOff+(int)width-2; i++) {
+            draw->DrawFillString(i,yOff+height-1,L"\x2500",backgroundColor);
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
+        case Display::statusbarBackgroundFillIndex:
+          draw->PushForeground(Display::backgroundColor);
+          draw->FillRectangle(x,y,w,h);
+          draw->PopForeground();
+
+          draw->PushFont(OS::display->GetFont());
+          draw->PushForeground(Display::blackColor);
+
+          for (int i=xOff; i<=xOff+(int)width-1; i++) {
+            draw->DrawFillString(i,yOff,L"\x2500",backgroundColor);
+          }
+
+          draw->PopForeground();
+          draw->PopFont();
+          break;
         default:
           assert(false);
           break;
@@ -308,48 +593,18 @@ namespace Lum {
       : frame(frame)
       {
         switch (frame) {
-        case Display::buttonFrameIndex:
-        case Display::positiveButtonFrameIndex:
-        case Display::negativeButtonFrameIndex:
-        case Display::defaultButtonFrameIndex:
-        case Display::toolbarButtonFrameIndex:
-        case Display::editFrameIndex:
-          leftBorder=1;
-          rightBorder=leftBorder;
-          topBorder=0;
-          bottomBorder=topBorder;
-          break;
-        case Display::hprogressFrameIndex:
-        case Display::vprogressFrameIndex:
-        case Display::listboxFrameIndex:
         case Display::tabFrameIndex:
-        case Display::menuWindowFrameIndex:
           leftBorder=1;
           rightBorder=leftBorder;
           topBorder=1;
           bottomBorder=topBorder;
           break;
-        case Display::tabRiderFrameIndex:
-          leftBorder=1;
-          rightBorder=leftBorder;
-          topBorder=1;
-          bottomBorder=0;
-          break;
-        case Display::hknobBoxFrameIndex:
-        case Display::vknobBoxFrameIndex:
-        case Display::scrolledFrameIndex:
+        default:
           leftBorder=0;
           rightBorder=leftBorder;
           topBorder=0;
           bottomBorder=topBorder;
           break;
-        case Display::columnFrameIndex:
-        case Display::menuPulldownFrameIndex:
-          leftBorder=1;
-          rightBorder=leftBorder;
-          topBorder=0;
-          bottomBorder=topBorder;
-          break;
         }
 
         minWidth=leftBorder+rightBorder;
@@ -365,74 +620,7 @@ namespace Lum {
         Color backgroundColor=OS::display->GetColor(Display::backgroundColor);
 
         switch (frame) {
-        case Display::buttonFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x,i,L"[",dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          }
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x+w-1,i,L"]",dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-        case Display::positiveButtonFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x,i,L"<",dynamic_cast<Theme*>(OS::display->GetTheme())->positiveButtonBackgroundColor);
-          }
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x+w-1,i,L">",dynamic_cast<Theme*>(OS::display->GetTheme())->positiveButtonBackgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-        case Display::negativeButtonFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x,i,L"[",dynamic_cast<Theme*>(OS::display->GetTheme())->negativeButtonBackgroundColor);
-          }
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x+w-1,i,L"]",dynamic_cast<Theme*>(OS::display->GetTheme())->negativeButtonBackgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-
-        case Display::defaultButtonFrameIndex:
-        case Display::toolbarButtonFrameIndex:
-        case Display::editFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x,i,L"[",dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          }
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x+w-1,i,L"]",dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-        case Display::hprogressFrameIndex:
-        case Display::vprogressFrameIndex:
-        case Display::listboxFrameIndex:
         case Display::tabFrameIndex:
-        case Display::menuWindowFrameIndex:
           draw->PushFont(OS::display->GetFont());
           draw->PushForeground(Display::blackColor);
 
@@ -464,67 +652,6 @@ namespace Lum {
           draw->PopForeground();
           draw->PopFont();
           break;
-        case Display::tabRiderFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          draw->DrawFillString(x,y,L"\x250c",backgroundColor);
-          draw->DrawFillString(x+w-1,y,L"\x2510",backgroundColor);
-
-          // top
-          for (int i=x+1; i<=x+(int)w-2; i++) {
-            draw->DrawFillString(i,y,L"\x2500",backgroundColor);
-          }
-
-          // left
-          for (int i=y+1; i<=y+(int)h-1; i++) {
-            draw->DrawFillString(x,i,L"\x2502",backgroundColor);
-          }
-
-          // right
-          for (int i=y+1; i<=y+(int)h-1; i++) {
-            draw->DrawFillString(x+w-1,i,L"\x2502",backgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-
-        case Display::hknobBoxFrameIndex:
-        case Display::vknobBoxFrameIndex:
-          // no frame
-          break;
-        case Display::columnFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x,i,L" ",dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          }
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x+w-1,i,L" ",dynamic_cast<Theme*>(OS::display->GetTheme())->buttonBackgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-        case Display::menuPulldownFrameIndex:
-          draw->PushFont(OS::display->GetFont());
-          draw->PushForeground(Display::blackColor);
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x,i,L" ",backgroundColor);
-          }
-
-          for (size_t i=y; i<y+(size_t)h; ++i) {
-            draw->DrawFillString(x+w-1,i,L" ",backgroundColor);
-          }
-
-          draw->PopForeground();
-          draw->PopFont();
-          break;
-
         default:
           assert(false);
           break;
@@ -583,6 +710,8 @@ namespace Lum {
         }
 
         fill[Display::backgroundFillIndex]=new TextFill(Display::backgroundFillIndex);
+        fill[Display::tableBackgroundFillIndex]=new TextFill(Display::tableBackgroundFillIndex);
+        fill[Display::tableBackground2FillIndex]=new TextFill(Display::tableBackground2FillIndex);
         fill[Display::buttonBackgroundFillIndex]=new TextFill(Display::buttonBackgroundFillIndex);
         fill[Display::positiveButtonBackgroundFillIndex]=new TextFill(Display::positiveButtonBackgroundFillIndex);
         fill[Display::negativeButtonBackgroundFillIndex]=new TextFill(Display::negativeButtonBackgroundFillIndex);
@@ -590,65 +719,53 @@ namespace Lum {
         fill[Display::toolbarButtonBackgroundFillIndex]=new TextFill(Display::toolbarButtonBackgroundFillIndex);
         fill[Display::scrollButtonBackgroundFillIndex]=new TextFill(Display::scrollButtonBackgroundFillIndex);
         fill[Display::comboBackgroundFillIndex]=fill[Display::buttonBackgroundFillIndex];
-        fill[Display::tableBackgroundFillIndex]=new TextFill(Display::tableBackgroundFillIndex);
-        fill[Display::tableBackground2FillIndex]=new TextFill(Display::tableBackground2FillIndex);
-        fill[Display::entryBackgroundFillIndex]=fill[Display::tableBackgroundFillIndex];
-        fill[Display::helpBackgroundFillIndex]=new TextFill(Display::helpBackgroundFillIndex);
-        fill[Display::hprogressBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::editComboBackgroundFillIndex]=fill[Display::buttonBackgroundFillIndex];
+        fill[Display::entryBackgroundFillIndex]=new TextFill(Display::entryBackgroundFillIndex);
+        fill[Display::hprogressBackgroundFillIndex]=new TextFill(Display::hprogressBackgroundFillIndex);
         fill[Display::hprogressFillIndex]=new TextFill(Display::hprogressFillIndex);
-        fill[Display::vprogressBackgroundFillIndex]=fill[Display::backgroundFillIndex];
-        fill[Display::vprogressFillIndex]=fill[Display::hprogressFillIndex];
+        fill[Display::vprogressBackgroundFillIndex]=new TextFill(Display::vprogressBackgroundFillIndex);
+        fill[Display::vprogressFillIndex]=new TextFill(Display::vprogressFillIndex);
         fill[Display::hknobBoxFillIndex]=fill[Display::backgroundFillIndex];
         fill[Display::vknobBoxFillIndex]=fill[Display::backgroundFillIndex];
         fill[Display::tabBackgroundFillIndex]=fill[Display::backgroundFillIndex];
-        fill[Display::tabRiderBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::tabRiderBackgroundFillIndex]=new TextFill(Display::tabRiderBackgroundFillIndex);
         fill[Display::columnBackgroundFillIndex]=fill[Display::buttonBackgroundFillIndex];
+        fill[Display::columnLeftBackgroundFillIndex]=fill[Display::buttonBackgroundFillIndex];
+        fill[Display::columnMiddleBackgroundFillIndex]=fill[Display::buttonBackgroundFillIndex];
+        fill[Display::columnRightBackgroundFillIndex]=fill[Display::buttonBackgroundFillIndex];
         fill[Display::columnEndBackgroundFillIndex]=fill[Display::backgroundFillIndex];
         fill[Display::menuStripBackgroundFillIndex]=new TextFill(Display::menuStripBackgroundFillIndex);
         fill[Display::menuPulldownBackgroundFillIndex]=new TextFill(Display::menuPulldownBackgroundFillIndex);
         fill[Display::menuEntryBackgroundFillIndex]=new TextFill(Display::menuEntryBackgroundFillIndex);
+        fill[Display::menuWindowBackgroundFillIndex]=new TextFill(Display::menuWindowBackgroundFillIndex);
+        fill[Display::popupWindowBackgroundFillIndex]=new TextFill(Display::popupWindowBackgroundFillIndex);
+        fill[Display::dialogWindowBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::tooltipWindowBackgroundFillIndex]=fill[Display::backgroundFillIndex];
         fill[Display::graphBackgroundFillIndex]=new TextFill(Display::graphBackgroundFillIndex);
-        fill[Display::toolbarBackgroundFillIndex]=new TextFill(Display::toolbarBackgroundFillIndex);
+        fill[Display::toolbarBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::labelBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::listboxBackgroundFillIndex]=new TextFill(Display::listboxBackgroundFillIndex);
+        fill[Display::scrolledBackgroundFillIndex]=new TextFill(Display::scrolledBackgroundFillIndex);
+        fill[Display::hscrollBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::vscrollBackgroundFillIndex]=fill[Display::backgroundFillIndex];
+        fill[Display::boxedBackgroundFillIndex]=new TextFill(Display::boxedBackgroundFillIndex);
+        fill[Display::plateBackgroundFillIndex]=new TextFill(Display::plateBackgroundFillIndex);
+        fill[Display::statusbarBackgroundFillIndex]=new TextFill(Display::statusbarBackgroundFillIndex);
 
-        frame[Display::buttonFrameIndex]=new TextFrame(Display::buttonFrameIndex);
-        frame[Display::positiveButtonFrameIndex]=new TextFrame(Display::positiveButtonFrameIndex);
-        frame[Display::negativeButtonFrameIndex]=new TextFrame(Display::negativeButtonFrameIndex);
-        frame[Display::defaultButtonFrameIndex]=new TextFrame(Display::defaultButtonFrameIndex);
-        frame[Display::toolbarButtonFrameIndex]=new TextFrame(Display::toolbarButtonFrameIndex);
-        frame[Display::scrollButtonFrameIndex]=emptyFrame;
-        frame[Display::editFrameIndex]=new TextFrame(Display::editFrameIndex);
-        frame[Display::hprogressFrameIndex]=new TextFrame(Display::hprogressFrameIndex);;
-        frame[Display::vprogressFrameIndex]=new TextFrame(Display::vprogressFrameIndex);;
-        frame[Display::hknobBoxFrameIndex]=emptyFrame;
-        frame[Display::vknobBoxFrameIndex]=emptyFrame;
-        frame[Display::hscrollFrameIndex]=emptyFrame;
-        frame[Display::vscrollFrameIndex]=emptyFrame;
         frame[Display::tabFrameIndex]=new TextFrame(Display::tabFrameIndex);
-        frame[Display::tabRiderFrameIndex]=new TextFrame(Display::tabRiderFrameIndex);
-        frame[Display::listboxFrameIndex]=new TextFrame(Display::listboxFrameIndex);
-        frame[Display::scrolledFrameIndex]=emptyFrame;
-        frame[Display::columnFrameIndex]=new TextFrame(Display::columnFrameIndex);
+        /*frame[Display::columnFrameIndex]=new TextFrame(Display::columnFrameIndex);
         frame[Display::columnLeftFrameIndex]=frame[Display::columnFrameIndex];
         frame[Display::columnMiddleFrameIndex]=frame[Display::columnFrameIndex];
         frame[Display::columnRightFrameIndex]=frame[Display::columnFrameIndex];
-        frame[Display::columnEndFrameIndex]=emptyFrame;
-        frame[Display::comboFrameIndex]=frame[Display::buttonFrameIndex];
-        frame[Display::editComboFrameIndex]=emptyFrame;
-        frame[Display::mainWindowFrameIndex]=emptyFrame;
-        frame[Display::menuWindowFrameIndex]=new TextFrame(Display::menuWindowFrameIndex);
-        frame[Display::popupWindowFrameIndex]=emptyFrame;
-        frame[Display::tooltipWindowFrameIndex]=emptyFrame;
+        frame[Display::columnEndFrameIndex]=emptyFrame;*/
         frame[Display::hscaleFrameIndex]=emptyFrame;
         frame[Display::vscaleFrameIndex]=emptyFrame;
         frame[Display::focusFrameIndex]=emptyFrame;
-        frame[Display::statusbarFrameIndex]=emptyFrame;
         frame[Display::statuscellFrameIndex]=emptyFrame;
-        frame[Display::plateFrameIndex]=emptyFrame;
+        //frame[Display::plateFrameIndex]=emptyFrame;
         frame[Display::valuebarFrameIndex]=emptyFrame;
         frame[Display::groupFrameIndex]=emptyFrame; // TODO
-        frame[Display::menuStripFrameIndex]=emptyFrame;
-        frame[Display::menuPulldownFrameIndex]=new TextFrame(Display::menuPulldownFrameIndex);
-        frame[Display::labelFrameIndex]=emptyFrame;
+        //frame[Display::menuPulldownFrameIndex]=new TextFrame(Display::menuPulldownFrameIndex);
 
         image[Display::hknobImageIndex]=new TextImage(Display::hknobImageIndex);
         image[Display::vknobImageIndex]=new TextImage(Display::vknobImageIndex);
@@ -656,10 +773,10 @@ namespace Lum {
         image[Display::arrowRightImageIndex]=new TextImage(Display::arrowRightImageIndex);
         image[Display::arrowUpImageIndex]=new TextImage(Display::arrowUpImageIndex);
         image[Display::arrowDownImageIndex]=new TextImage(Display::arrowDownImageIndex);
-        image[Display::arrowScrollLeftImageIndex]=new TextImage(Display::arrowScrollLeftImageIndex);
-        image[Display::arrowScrollRightImageIndex]=new TextImage(Display::arrowScrollRightImageIndex);
-        image[Display::arrowScrollUpImageIndex]=new TextImage(Display::arrowScrollUpImageIndex);
-        image[Display::arrowScrollDownImageIndex]=new TextImage(Display::arrowScrollDownImageIndex);
+        image[Display::scrollLeftImageIndex]=new TextImage(Display::scrollLeftImageIndex);
+        image[Display::scrollRightImageIndex]=new TextImage(Display::scrollRightImageIndex);
+        image[Display::scrollUpImageIndex]=new TextImage(Display::scrollUpImageIndex);
+        image[Display::scrollDownImageIndex]=new TextImage(Display::scrollDownImageIndex);
         image[Display::comboImageIndex]=new TextImage(Display::comboImageIndex);
         image[Display::comboEditButtonImageIndex]=new TextImage(Display::comboEditButtonImageIndex);
         image[Display::comboDividerImageIndex]=new TextImage(Display::comboDividerImageIndex);
@@ -675,6 +792,8 @@ namespace Lum {
         image[Display::menuCheckImageIndex]=new TextImage(Display::menuCheckImageIndex);
         image[Display::menuRadioImageIndex]=new TextImage(Display::menuRadioImageIndex);
         image[Display::closeImageIndex]=new TextImage(Display::closeImageIndex);
+        image[Display::hpaneHandleImageIndex]=new TextImage(Display::hpaneHandleImageIndex);
+        image[Display::vpaneHandleImageIndex]=new TextImage(Display::vpaneHandleImageIndex);
       }
 
       Theme::~Theme()
@@ -737,6 +856,8 @@ namespace Lum {
           return false;
           break;
         }
+
+        return false;
       }
 
       void Theme::DrawObject(DrawInfo* draw,
