@@ -44,53 +44,6 @@ namespace Lum {
       {
       }
 
-      class Prefs : public OS::Display::Prefs
-      {
-      public:
-        Prefs();
-
-        void Initialize();
-
-        void ReadConfig(Config::Node *top);
-      };
-
-      /**
-        Initializes an instance.
-      */
-      Prefs::Prefs()
-      {
-        // no code
-      }
-
-      void Prefs::Initialize()
-      {
-        propFont="Segoe UI";
-        propFontSize=9;
-
-        fixedFont="Courier New";
-        fixedFontSize=9;
-
-        //p.contextTimer=2500
-      }
-
-      void Prefs::ReadConfig(Config::Node *top)
-      {
-        Config::Node *node,*sub;
-
-        node=top->GetChild(L"theme");
-        if (node!=NULL) {
-          theme=node->GetValue();
-        }
-
-        sub=top->GetChild(L"Fonts");
-        if (sub!=NULL) {
-          sub->GetAttribute(L"proportional",propFont);
-          sub->GetAttribute(L"proportionalSize",propFontSize);
-          sub->GetAttribute(L"fixed",fixedFont);
-          sub->GetAttribute(L"fixedSize",fixedFontSize);
-        }
-      }
-
       Display::Display()
        : selectObject(NULL),
          exit(true),
@@ -492,6 +445,11 @@ namespace Lum {
         }
       }
 
+      bool Display::HasClipboard() const
+      {
+        return !GetClipboard().empty();
+      }
+
       void Display::PutBackEvent(OS::Event* /*event*/, OS::Window* /*destWin*/)
       {
         // TODO
@@ -568,16 +526,6 @@ namespace Lum {
         //D.smallChess=d.CreateBitmapPattern(D.disablePattern,D.disableWidth,D.disableHeight);
         //D.bigChess=d.CreateBitmapPattern(D.bigChessPattern,D.bigChessWidth,D.bigChessHeight);
 
-        prefs=new OS::Win32::Prefs();
-        prefs->Initialize();
-
-        Lum::Prefs::LoadConfig(GetPrefsName());
-        Lum::Prefs::ReadDisplayConfig();
-        if (!prefs->theme.empty()) {
-          Lum::Prefs::LoadTheme(GetThemeName());
-          Lum::Prefs::ReadDisplayTheme();
-        }
-
         if (driver->GetDriverName()==L"Win32") {
           theme=new Win32Theme(this);
         }
@@ -620,13 +568,6 @@ namespace Lum {
 
         multiClickTime=200;
 
-        Lum::Prefs::InitializePrefs(prefs);
-        Lum::Prefs::ReadOthersConfig();
-        if (!prefs->theme.empty()) {
-          Lum::Prefs::ReadOthersTheme();
-        }
-        Lum::Prefs::FreeData();
-
         return true;
       }
 
@@ -690,9 +631,6 @@ namespace Lum {
 
         OS::Base::Display::Close();
 
-
-        Lum::Prefs::FreePrefs();
-
         /*
         if (selectObject!=NULL) {
           CancelSelection();
