@@ -73,8 +73,6 @@
   #include <Lum/OS/Cairo/Display.h>
 #endif
 
-#include <Lum/Prefs/Base.h>
-
 namespace Lum {
   namespace OS {
     namespace X11 {
@@ -170,62 +168,6 @@ namespace Lum {
       };
 */
 
-      class Prefs : public ::Lum::OS::Display::Prefs
-      {
-      private:
-        Display* display;
-
-      public:
-        Prefs(Display* display);
-
-        void Initialize();
-
-        void ReadConfig(::Lum::Config::Node *top);
-      };
-
-      /**
-        Initializes an instance.
-      */
-      Prefs::Prefs(Display* display)
-      : display(display)
-      {
-        // no code
-      }
-
-      void Prefs::Initialize()
-      {
-#ifdef HAVE_LIB_HILDON
-        theme=L"Gtk";
-        propFont="Bitstream Vera Sans";
-        propFontSize=16;
-#else
-        propFont="helvetica";
-        propFontSize=12;
-#endif
-        fixedFont="fixed";
-        fixedFontSize=13;
-
-        //p.contextTimer=2500;
-      }
-
-      void Prefs::ReadConfig(Config::Node *top)
-      {
-        Config::Node *node,*sub;
-
-        node=top->GetChild(L"theme");
-        if (node!=NULL) {
-          theme=node->GetValue();
-        }
-
-        sub=top->GetChild(L"Fonts");
-        if (sub!=NULL) {
-          sub->GetAttribute(L"proportional",propFont);
-          sub->GetAttribute(L"proportionalSize",propFontSize);
-          sub->GetAttribute(L"fixed",fixedFont);
-          sub->GetAttribute(L"fixedSize",fixedFontSize);
-        }
-      }
-
       double Display::GetDPI() const
       {
         return dpi;
@@ -1312,19 +1254,12 @@ namespace Lum {
         D.bigChess:=d.CreateBitmapPattern(D.bigChessPattern,D.bigChessWidth,D.bigChessHeight);
 
                       */
-        prefs=new X11::Prefs(this);
-        prefs->Initialize();
-
-        Lum::Prefs::LoadConfig(GetPrefsName());
-        Lum::Prefs::ReadDisplayConfig();
-        if (!prefs->theme.empty()) {
-          Lum::Prefs::LoadTheme(GetThemeName());
-          Lum::Prefs::ReadDisplayTheme();
-        }
 
 #if defined(HAVE_LIB_GTK)
-        if ((driver->GetDriverName()==L"X11" ||
-             driver->GetDriverName()==L"CairoX11")) {
+        if (((driver->GetDriverName()==L"X11" ||
+             driver->GetDriverName()==L"CairoX11")) &&
+             (getenv("ILLUMINATION_THEME")==NULL ||
+              strcmp(getenv("ILLUMINATION_THEME"),"X11"))!=0) {
           theme=new GtkTheme(this);
         }
         else {
@@ -1461,13 +1396,6 @@ namespace Lum {
 
         multiClickTime=200;
 
-        Lum::Prefs::InitializePrefs(prefs);
-        Lum::Prefs::ReadOthersConfig();
-        if (!prefs->theme.empty()) {
-          Lum::Prefs::ReadOthersTheme();
-        }
-        Lum::Prefs::FreeData();
-
 #if 0
         if (getenv("SESSION_MANAGER")!=NULL) {
           SmcCallbacks callbacks;
@@ -1541,8 +1469,6 @@ namespace Lum {
         }
 #endif
 
-        Lum::Prefs::FreePrefs();
-
         if (selectObject!=NULL) {
           CancelSelection();
         }
@@ -1670,6 +1596,10 @@ namespace Lum {
           return clipboard;
         }
 
+        if (!HasClipboard()) {
+          return L"";
+        }
+
         XEvent         event;
         Atom           clipboardType=XA_STRING;
         Atom           retType;
@@ -1780,11 +1710,16 @@ namespace Lum {
       {
         if (!clipboard.empty()) {
           selClearPend=true;
-          XSetSelectionOwner(display,atoms[clipboardAtom],None,CurrentTime);
+          ::XSetSelectionOwner(display,atoms[clipboardAtom],None,CurrentTime);
           clipboard=L"";
         }
       }
 
+      bool Display::HasClipboard() const
+      {
+        return ::XGetSelectionOwner(display,atoms[clipboardAtom])!=None;
+      }
+
       void Display::PutBackEvent(OS::Event* event,
                                  OS::Window* destWin)
       {
