@@ -27,18 +27,6 @@
 
 namespace Lum {
 
-  Object::Prefs::Prefs(const std::wstring& name)
-  : Lum::Prefs::Prefs(name)
-  {
-    // no code
-  }
-
-  void Object::Prefs::Initialize()
-  {
-    background=NULL;
-    frame=new OS::EmptyFrame();
-  }
-
   Visitor::~Visitor()
   {
     // no code
@@ -97,7 +85,6 @@ namespace Lum {
 
   Object::Object()
   : parent(NULL),
-    prefs(NULL),
     x(0),y(0),width(0),height(0),
     minWidth(0),minHeight(0),
     maxWidth(32000),maxHeight(32000),
@@ -117,8 +104,8 @@ namespace Lum {
     requestsFocus(false),
     requestsLabelFocus(false),
     requestsKeyboard(false),
-    canDrawMouseActive(false),
     mouseActive(false),
+    redrawOnMouseActive(false),
     inited(false),
     shortcutAlways(false),
     window(NULL),menu(NULL),help(NULL),
@@ -175,28 +162,6 @@ namespace Lum {
     menu=NULL;
   }
 
-  /**
-    Assign a preferences object the object.
-  */
-  void Object::SetPrefs(Prefs* prefs)
-  {
-    this->prefs=prefs;
-
-    if (prefs->background.Valid()) {
-      SetBackground(prefs->background);
-    }
-
-    if (prefs->hSize.IsSizeSet()) {
-      SetWidth(prefs->hSize.mode,prefs->hSize.size);
-    }
-
-    if (prefs->vSize.IsSizeSet()) {
-      SetWidth(prefs->vSize.mode,prefs->vSize.size);
-    }
-
-    frame=prefs->frame;
-  }
-
   /**
     Assign a Controller to the object.
   */
@@ -289,6 +254,46 @@ namespace Lum {
     return oMaxHeight;
   }
 
+  size_t Object::GetTopBorder() const
+  {
+    if (background.Valid()) {
+      return background->topBorder;
+    }
+    else {
+      return 0;
+    }
+  }
+
+  size_t Object::GetBottomBorder() const
+  {
+    if (background.Valid()) {
+      return background->bottomBorder;
+    }
+    else {
+      return 0;
+    }
+  }
+
+  size_t Object::GetLeftBorder() const
+  {
+    if (background.Valid()) {
+      return background->leftBorder;
+    }
+    else {
+      return 0;
+    }
+  }
+
+  size_t Object::GetRightBorder() const
+  {
+    if (background.Valid()) {
+      return background->rightBorder;
+    }
+    else {
+      return 0;
+    }
+  }
+
   /**
     Returns true if the object has a baseline, else false.
     Objects normally have a baseline if they have textual
@@ -311,6 +316,12 @@ namespace Lum {
     because the baseline must always be below the upper edge of the
     control.
 
+    Since this method is calledbefore calcSize() is called,
+    you cannot rely on stuff like y-oY. You must calculate
+    to position of text relative to the outer bounds of the control
+    yourself, taking into account a background with border
+    manually.
+
     By default returns 0.
   */
   size_t Object::GetBaseline() const
@@ -399,6 +410,11 @@ namespace Lum {
     this->background=background;
   }
 
+  OS::Fill* Object::GetBackground() const
+  {
+    return background.Get();
+  }
+
   /**
     Assign a label to the object. Some object may support some
     tricky operations with their label. A checkbox f.e. may delegate its
@@ -490,16 +506,6 @@ namespace Lum {
     return GetWindow()->GetDrawInfo();
   }
 
-  void Object::SetFrame(OS::Frame* frame)
-  {
-    this->frame=frame;
-  }
-
-  OS::Frame* Object::GetFrame() const
-  {
-    return frame.Get();
-  }
-
   OS::Color Object::GetTextColor(OS::DrawInfo *draw) const
   {
      if (draw->disabled) {
@@ -559,6 +565,16 @@ namespace Lum {
     return menu;
   }
 
+  /**
+    By implementing this method in the derived class you can
+    arrange some preparation like correctly settings models
+    referenced in a popup menu, before the menu gets opened.
+   */
+  void Object::PrepareMenu()
+  {
+    // No code - the default implementation does nothing
+  }
+
   bool Object::DisplayFocus() const
   {
     return hasFocus || showFocus;
@@ -1178,14 +1194,16 @@ namespace Lum {
     oMaxWidth=maxWidth;
     oMaxHeight=maxHeight;
 
-    oWidth+=frame->leftBorder+frame->rightBorder;
-    oHeight+=frame->topBorder+frame->bottomBorder;
+    if (background.Valid()) {
+      oWidth+=background->leftBorder+background->rightBorder;
+      oHeight+=background->topBorder+background->bottomBorder;
 
-    oMinWidth+=frame->leftBorder+frame->rightBorder;
-    oMinHeight+=frame->topBorder+frame->bottomBorder;
+      oMinWidth+=background->leftBorder+background->rightBorder;
+      oMinHeight+=background->topBorder+background->bottomBorder;
 
-    oMaxWidth+=frame->leftBorder+frame->rightBorder;
-    oMaxHeight+=frame->topBorder+frame->bottomBorder;
+      oMaxWidth+=background->leftBorder+background->rightBorder;
+      oMaxHeight+=background->topBorder+background->bottomBorder;
+    }
 
     if (!horizontalFlex) {
       oMinWidth=oWidth;
@@ -1228,8 +1246,10 @@ namespace Lum {
     this->x=x;
     this->y=y;
 
-    this->x+=frame->leftBorder;
-    this->y+=frame->topBorder;
+    if (background.Valid()) {
+      this->x+=background->leftBorder;
+      this->y+=background->topBorder;
+    }
 
     if (oldOX!=oX || oldOY!=oY) {
       layouted=false;
@@ -1265,7 +1285,10 @@ namespace Lum {
 
     if (horizontalFlex) {
       oWidth=std::max(width,oMinWidth);
-      this->width=oWidth-frame->leftBorder-frame->rightBorder;
+      this->width=oWidth;
+      if (background.Valid()) {
+        this->width-=background->leftBorder+background->rightBorder;
+      }
     }
 
     if (oldOWidth!=oWidth) {
@@ -1281,7 +1304,10 @@ namespace Lum {
 
     if (verticalFlex) {
       oHeight=std::max(height,oMinHeight);
-      this->height=oHeight-frame->topBorder-frame->bottomBorder;
+      this->height=oHeight;
+      if (background.Valid()) {
+        this->height-=background->topBorder+background->bottomBorder;
+      }
     }
 
     if (oldOHeight!=oHeight) {
@@ -1477,37 +1503,35 @@ namespace Lum {
   void Object::DrawBackgroundWithDrawInfo(OS::DrawInfo* draw,
                                           int x, int y, size_t w, size_t h)
   {
-    Object *object;
-
     // We clip the drawing rectangle to the bound of the object since we cannot draw
     // anything outside the object!
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
-    object=this;
+    Object *object=this;
+
     while (object!=NULL && !object->background.Valid()) {
       object=object->parent;
     }
 
-    if (object!=NULL) {
-      assert(x>=object->x);
-      //object->Intersect(x,y,w,h);
+    if (object!=NULL && object->background.Valid()) {
+      assert(x>=object->oX);
+
+      if (object->background->transparentBorder) {
+        object->DrawParentBackgroundWithDrawInfo(draw,x,y,w,h);
+      }
+
       object->background->Draw(draw,
-                               object->x,object->y,
-                               object->width,object->height,
+                               object->GetOX(),object->GetOY(),
+                               object->GetOWidth(),object->GetOHeight(),
                                x,y,w,h);
     }
     else {
-      object=this;
-      while (object->parent!=NULL) {
-        object=object->parent;
-      }
-
       OS::display->GetFill(OS::Display::backgroundFillIndex)->Draw(draw,
-                                                                   object->GetX(),object->GetY(),
-                                                                   object->GetWidth(),
-                                                                   object->GetHeight(),
+                                                                   GetOX(),GetOY(),
+                                                                   GetOWidth(),
+                                                                   GetOHeight(),
                                                                    x,y,w,h);
     }
   }
@@ -1525,7 +1549,8 @@ namespace Lum {
     draw->selected=false;
 
     if (parent!=NULL) {
-      if (!parent->Intersect(x,y,w,h)) {
+      if (!parent->OIntersect(x,y,w,h)) {
+        draw->selected=selected;
         return;
       }
 
@@ -1533,6 +1558,7 @@ namespace Lum {
     }
     else {
       if (!OIntersect(x,y,w,h)) {
+        draw->selected=selected;
         return;
       }
 
@@ -1545,18 +1571,6 @@ namespace Lum {
     draw->selected=selected;
   }
 
-  /**
-    Draw the given background relative to the current object.
-  */
-  void Object::DrawBackgroundRelative(OS::DrawInfo* draw,
-                                      OS::Fill* background,
-                                      int x, int y, size_t w, size_t h)
-  {
-    background->Draw(draw,
-                     GetX(),GetY(),GetWidth(),GetHeight(),
-                     x,y,w,h);
-  }
-
   /**
     Tells the object to draw itself at the given position and with the mode
     set in OS::DrawInfo.mode.
@@ -1594,36 +1608,12 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo  *draw=GetDrawInfo();
     LayoutVisitor layoutVisitor;
 
     if (!layouted) {
       this->Layout();
       VisitChildren(layoutVisitor,true);
     }
-
-    if (x>=this->x &&
-        x+(int)w<this->x+(int)this->width &&
-        y>=this->y &&
-        y+(int)h<this->y+(int)this->height) {
-      // Area to be drawn is completely inside the frame, so we do not need
-      // to redraw the frame.
-      return;
-    }
-
-    if (frame->minWidth>0 || frame->minHeight>0) {
-      if (frame->alpha) {
-        draw->PushClipBegin(oX,oY,oWidth,oHeight);
-        draw->SubClipRegion(this->x,this->y,this->width,this->height);
-        draw->PushClipEnd();
-        DrawParentBackground(oX,oY,oWidth,oHeight);
-        frame->Draw(draw,oX,oY,oWidth,oHeight);
-        draw->PopClip();
-      }
-      else {
-        frame->Draw(draw,oX,oY,oWidth,oHeight);
-      }
-    }
   }
 
   /**
@@ -1699,21 +1689,9 @@ namespace Lum {
     return false;
   }
 
-  /**
-    Is the object is able to draw itself differently when the mouseis over it,
-    set this to true.
-  */
-  void Object::SetCanDrawMouseActive(bool canDraw)
+  void Object::SetRedrawOnMouseActive(bool redraw)
   {
-    canDrawMouseActive=canDraw;
-  }
-
-  /**
-    Returns true if the object draws itself differently when the mouse is over it.
-  */
-  bool Object::CanDrawMouseActive() const
-  {
-    return canDrawMouseActive;
+    redrawOnMouseActive=redraw;
   }
 
   /**
@@ -1723,7 +1701,7 @@ namespace Lum {
   {
     mouseActive=true;
 
-    if (visible && canDrawMouseActive) {
+    if (visible && redrawOnMouseActive) {
       Redraw();
     }
   }
@@ -1735,7 +1713,7 @@ namespace Lum {
   {
     mouseActive=false;
 
-    if (visible && canDrawMouseActive) {
+    if (visible && redrawOnMouseActive) {
       Redraw();
     }
   }
@@ -1948,8 +1926,19 @@ namespace Lum {
 
       bool Visit(Object* object)
       {
-        draw->SubClipRegion(object->GetOX(),object->GetOY(),
-                            object->GetOWidth(),object->GetOHeight());
+        OS::Fill* background=object->GetBackground();
+        if (background!=NULL) {
+          if (!background->transparentBorder) {
+            draw->SubClipRegion(object->GetOX(),object->GetOY(),
+                                object->GetOWidth(),object->GetOHeight());
+          }
+          else {
+            draw->SubClipRegion(object->GetOX()+background->leftBorder,
+                                object->GetOY()+background->topBorder,
+                                object->GetOWidth()-background->leftBorder-background->rightBorder,
+                                object->GetOHeight()-background->topBorder-background->bottomBorder);
+          }
+        }
         return true;
       }
     };
@@ -1990,7 +1979,7 @@ namespace Lum {
 
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -2125,6 +2114,23 @@ namespace Lum {
     }
   }
 
+  bool Component::HasBaseline() const
+  {
+    if (container!=NULL) {
+      return container->HasBaseline();
+    }
+    else {
+      return false;
+    }
+  }
+
+  size_t Component::GetBaseline() const
+  {
+    assert(inited && container!=NULL);
+
+    return container->GetBaseline();
+  }
+
   void Component::Layout()
   {
     container->MoveResize(x,y,width,height);
@@ -2136,7 +2142,7 @@ namespace Lum {
   {
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -2174,6 +2180,23 @@ namespace Lum {
     }
   }
 
+  bool ControlComponent::HasBaseline() const
+  {
+    if (container!=NULL) {
+      return container->HasBaseline();
+    }
+    else {
+      return false;
+    }
+  }
+
+  size_t ControlComponent::GetBaseline() const
+  {
+    assert(inited && container!=NULL);
+
+    return container->GetBaseline();
+  }
+
   void ControlComponent::Layout()
   {
     container->MoveResize(x,y,width,height);
@@ -2185,7 +2208,7 @@ namespace Lum {
   {
     Control::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
