@@ -21,24 +21,9 @@
 
 namespace Lum {
 
-  static Placeholder::Prefs *prefs=new Placeholder::Prefs(L"Placeholder");
-
-  Placeholder::Prefs::Prefs(const std::wstring& name)
-    : Object::Prefs(name)
-  {
-    // no code
-  }
-
-  void Placeholder::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    frame=OS::display->GetFrame(OS::Display::plateFrameIndex);
-  }
-
   Placeholder::Placeholder()
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::plateBackgroundFillIndex));
   }
 
   void Placeholder::CalcSize()
@@ -56,16 +41,10 @@ namespace Lum {
   {
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
-    /* --- */
-
-    OS::DrawInfo *draw=GetDrawInfo();
-
-    draw->PushForeground(OS::Display::whiteColor);
-    draw->FillRectangle(x,y,w,h);
-    draw->PopForeground();
+    DrawBackground(x,y,w,h);
   }
 }
