@@ -21,12 +21,6 @@
 
 namespace Lum {
 
-  PopupControl::Prefs::Prefs(const std::wstring& name)
-  : Control::Prefs(name)
-  {
-    // no code
-  }
-
   PopupControl::PopupControl(Control* control)
   : control(control),button(new Button()),popupAction(new Model::Action())
   {
@@ -59,7 +53,7 @@ namespace Lum {
   size_t PopupControl::GetBaseline() const
   {
     if (control->HasBaseline()) {
-      return frame->topBorder+(height-control->GetOHeight())/2+control->GetBaseline();
+      return GetTopBorder()+(height-control->GetOHeight())/2+control->GetBaseline();
     }
     else {
       return 0;
