@@ -26,24 +26,9 @@
 
 namespace Lum {
 
-  static RGBControl::Prefs* prefs=new RGBControl::Prefs(L"RGBControl");
-
-  RGBControl::Prefs::Prefs(const std::wstring& name)
-    : ControlComponent::Prefs(name)
-  {
-    // no code
-  }
-
-  void RGBControl::Prefs::Initialize()
-  {
-    ControlComponent::Prefs::Initialize();
-  }
-
   RGBControl::RGBControl()
   : r(new Model::Int()),g(new Model::Int()),b(new Model::Int())
   {
-    SetPrefs(::Lum::prefs);
-
     r->SetRange(0,255);
     g->SetRange(0,255);
     b->SetRange(0,255);
