@@ -23,39 +23,13 @@
 
 namespace Lum {
 
-  static Slider::Prefs* prefs=new Slider::Prefs(L"Slider");
-
-  Slider::Prefs::Prefs(const std::wstring& name)
-    : Object::Prefs(name)
-  {
-    // no code
-  }
-
-  void Slider::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    hFrame=OS::display->GetFrame(OS::Display::hscaleFrameIndex);
-    vFrame=OS::display->GetFrame(OS::Display::hscaleFrameIndex);
-
-    hKnob=OS::display->GetImage(OS::Display::hscaleKnobImageIndex);
-    vKnob=OS::display->GetImage(OS::Display::vscaleKnobImageIndex);
-
-    hFilled=OS::display->GetImage(OS::Display::leftSliderImageIndex);
-    hUnfilled=OS::display->GetImage(OS::Display::rightSliderImageIndex);
-    vFilled=OS::display->GetImage(OS::Display::bottomSliderImageIndex);
-    vUnfilled=OS::display->GetImage(OS::Display::topSliderImageIndex);
-  }
-
   Slider::Slider()
   : boxFrame(NULL),knob(NULL),offset(0),corr(0),model(NULL),
     selected(false),useScale(false)
   {
-    SetPrefs(Lum::prefs);
-
     SetCanFocus(true);
     RequestFocus();
-    SetCanDrawMouseActive(true);
+    SetRedrawOnMouseActive(true);
   }
 
   void Slider::SetScale(bool useScale)
@@ -106,8 +80,8 @@ namespace Lum {
 
   HSlider::HSlider()
   {
-    knob=dynamic_cast<Prefs*>(prefs)->hKnob;
-    boxFrame=dynamic_cast<Prefs*>(prefs)->hFrame;
+    knob=OS::display->GetImage(OS::Display::hscaleKnobImageIndex);
+    boxFrame=OS::display->GetFrame(OS::Display::hscaleFrameIndex);
   }
 
   void HSlider::DrawKnob()
@@ -153,11 +127,14 @@ namespace Lum {
                    kStart,
                    knob->GetHeight());
 
-    dynamic_cast<Prefs*>(prefs)->hFilled->Draw(draw,
-                                               x+boxFrame->leftBorder,
-                                               y+offset,
-                                               width-boxFrame->minWidth,
-                                               knob->GetHeight());
+    OS::ImageRef filled=OS::display->GetImage(OS::Display::leftSliderImageIndex);
+    OS::ImageRef unfilled=OS::display->GetImage(OS::Display::rightSliderImageIndex);
+
+    filled->Draw(draw,
+                 x+boxFrame->leftBorder,
+                 y+offset,
+                 width-boxFrame->minWidth,
+                 knob->GetHeight());
 
     draw->PopClip();
 
@@ -168,11 +145,11 @@ namespace Lum {
                    width-boxFrame->minWidth-kStart-knob->GetWidth(),
                    knob->GetHeight());
 
-    dynamic_cast<Prefs*>(prefs)->hUnfilled->Draw(draw,
-                                                 x+boxFrame->leftBorder,
-                                                 y+offset,
-                                                 width-boxFrame->minWidth,
-                                                 knob->GetHeight());
+    unfilled->Draw(draw,
+                   x+boxFrame->leftBorder,
+                   y+offset,
+                   width-boxFrame->minWidth,
+                   knob->GetHeight());
 
     draw->PopClip();
 
@@ -380,8 +357,8 @@ namespace Lum {
 
   VSlider::VSlider()
   {
-    knob=dynamic_cast<Prefs*>(prefs)->vKnob;
-    boxFrame=dynamic_cast<Prefs*>(prefs)->vFrame;
+    knob=OS::display->GetImage(OS::Display::vscaleKnobImageIndex);
+    boxFrame=OS::display->GetFrame(OS::Display::hscaleFrameIndex);
   }
 
   void VSlider::DrawKnob()
@@ -427,11 +404,14 @@ namespace Lum {
                    knob->GetWidth(),
                    kStart);
 
-    dynamic_cast<Prefs*>(prefs)->vUnfilled->Draw(draw,
-                                                 x+offset,
-                                                 y+boxFrame->topBorder,
-                                                 knob->GetWidth(),
-                                                 height-boxFrame->minHeight);
+    OS::ImageRef filled=OS::display->GetImage(OS::Display::bottomSliderImageIndex);
+    OS::ImageRef unfilled=OS::display->GetImage(OS::Display::topSliderImageIndex);
+
+    unfilled->Draw(draw,
+                   x+offset,
+                   y+boxFrame->topBorder,
+                   knob->GetWidth(),
+                   height-boxFrame->minHeight);
 
     draw->PopClip();
 
@@ -442,11 +422,11 @@ namespace Lum {
                    knob->GetWidth(),
                    height-boxFrame->minHeight-kStart-knob->GetHeight());
 
-    dynamic_cast<Prefs*>(prefs)->vFilled->Draw(draw,
-                                               x+offset,
-                                               y+boxFrame->topBorder,
-                                               knob->GetWidth(),
-                                               height-boxFrame->minHeight);
+    filled->Draw(draw,
+                 x+offset,
+                 y+boxFrame->topBorder,
+                 knob->GetWidth(),
+                 height-boxFrame->minHeight);
 
     draw->PopClip();
 
