@@ -27,6 +27,7 @@ namespace Lum {
     SetCanFocus(active);
     if (active) {
       RequestFocus();
+      SetRedrawOnMouseActive(true);
     }
     SetRequestLabelFocus(true);
   }
@@ -146,7 +147,7 @@ namespace Lum {
 
     Control::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       draw->activated=false;
       draw->focused=false;
       return;
@@ -186,8 +187,6 @@ namespace Lum {
 
   void ImageState::CalcSize()
   {
-    SetCanDrawMouseActive(true/*image->GetDrawCap() & OS::Image::drawsActivated*/);
-
     OS::display->GetTheme()->GetObjectSize(object,minWidth,minHeight);
     width=minWidth;
     height=minHeight;
