@@ -27,25 +27,8 @@ namespace Lum {
 
   #define BLINK_MICRO 600000
 
-  static String::Prefs *prefs(new String::Prefs());
   static ControllerRef controller(new String::Controller());
 
-  String::Prefs::Prefs()
-  : Object::Prefs(L"String")
-  {
-    // no code
-  }
-
-  void String::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    background=OS::display->GetFill(OS::Display::entryBackgroundFillIndex);
-    frame=OS::display->GetFrame(OS::Display::editFrameIndex);
-
-    baseline=false;
-  }
-
   String::Controller::Controller()
   {
     RegisterKeyAction(L"C+x",actionCut);
@@ -148,7 +131,8 @@ namespace Lum {
   }
 
   String::String()
-  : textAlign(left),textWidth(256),visWidth(20),
+  : textAlign(left),textWidth(256),baseline(false),
+    visWidth(20),
     offset(0),cursor(0),
     markA((size_t)-1),markB((size_t)-1),
     font(::Lum::OS::display->GetFont()),
@@ -164,13 +148,14 @@ namespace Lum {
     eraseAction(new Model::Action),
     markAllAction(new Model::Action)
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::entryBackgroundFillIndex));
 
     SetController(::Lum::controller);
 
     SetCanFocus(true);
     RequestFocus();
     SetRequestsKeyboard(true);
+    SetRedrawOnMouseActive(true);
 
     cutAction->Disable();
     copyAction->Disable();
@@ -212,7 +197,7 @@ namespace Lum {
   {
     assert(inited);
 
-    return frame->topBorder+OS::display->GetTheme()->GetEntryHorizTextOffset()+(height-font->height) / 2 + font->ascent;
+    return GetTopBorder()+OS::display->GetTheme()->GetEntryHorizTextOffset()+(height-font->height) / 2 + font->ascent;
   }
 
   bool String::SetModel(Base::Model* model)
@@ -784,9 +769,7 @@ namespace Lum {
 
   void String::DrawCursor()
   {
-    int yOff=this->y+(height-font->height) / 2;
-
-    Redraw(cursorPos,yOff,1,y+font->height-1-yOff+1);
+    Redraw(cursorPos,y+(height-font->height) / 2,1,font->height);
   }
 
   std::wstring String::GetValue() const
@@ -838,7 +821,7 @@ namespace Lum {
     Control::Draw(x,y,w,h);
 
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       draw->focused=false;
       return;
     }
@@ -860,7 +843,7 @@ namespace Lum {
     }
 
     /* Draw optional baseline */
-    if (dynamic_cast<Prefs*>(prefs)->baseline) {
+    if (baseline) {
       draw->PushForeground(OS::Display::tableTextColor);
       draw->DrawLine(this->x+OS::display->GetTheme()->GetEntryHorizTextOffset(),yOff+font->ascent-1,
                      this->x+width-1-OS::display->GetTheme()->GetEntryHorizTextOffset(),yOff+font->ascent-1);
@@ -1016,15 +999,17 @@ namespace Lum {
     if (selected && !Selected() && cursorVisible) {
       if (OS::display->GetType()==OS::Display::typeTextual) {
         draw->PushForeground(OS::Display::fillColor);
-        draw->FillRectangle(cursorPos,yOff,1,y+font->height-1-yOff+1);
+        draw->FillRectangle(cursorPos,yOff,1,font->height);
         draw->PopForeground();
+        draw->PushFont(OS::display->GetFont());
         draw->PushForeground(OS::Display::fillTextColor);
         draw->DrawString(cursorPos,yOff,string.substr(cursor,1));
         draw->PopForeground();
+        draw->PopFont();
       }
       else {
         draw->PushForeground(OS::Display::tableTextColor);
-        draw->FillRectangle(cursorPos,yOff,1,y+font->height-1-yOff+1);
+        draw->FillRectangle(cursorPos,yOff,1,font->height);
         draw->PopForeground();
       }
     }
@@ -1060,6 +1045,16 @@ namespace Lum {
     }
   }
 
+  void String::PrepareMenu()
+  {
+    if (OS::display->HasClipboard()) {
+      pasteAction->Enable();
+    }
+    else {
+      pasteAction->Disable();
+    }
+  }
+
   bool String::HandleMouseEvent(const OS::MouseEvent& event)
   {
     if (!visible || !model.Valid() || model->IsNull()) {
