@@ -26,29 +26,6 @@
 
 namespace Lum {
 
-  static Tab::Prefs* prefs=new Tab::Prefs();
-
-  /* ----------------------- */
-
-  Tab::Prefs::Prefs()
-  : Control::Prefs(L"Tab")
-  {
-    // no code
-  }
-
-  void Tab::Prefs::Initialize()
-  {
-    Control::Prefs::Initialize();
-
-    hilightSelection=false;
-
-    tabFrame=OS::display->GetFrame(OS::Display::tabFrameIndex);
-    background=OS::display->GetFill(OS::Display::tabBackgroundFillIndex);
-
-    riderFrame=OS::display->GetFrame(OS::Display::tabRiderFrameIndex);
-    riderBackground=OS::display->GetFill(OS::Display::tabRiderBackgroundFillIndex);
-  }
-
   /* ----------------------- */
 
   class TabButton : public Control
@@ -79,7 +56,7 @@ namespace Lum {
   TabButton::TabButton(size_t index, Object* object, const Model::SizeTRef& model)
   : image(NULL),model(model),index(index)
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::tabRiderBackgroundFillIndex));
 
     this->model=model;
     SetModel(model.Get());
@@ -99,9 +76,6 @@ namespace Lum {
   void TabButton::CalcSize()
   {
     /* Let the frame calculate its size */
-    SetFrame(dynamic_cast<Tab::Prefs*>(prefs)->riderFrame);
-    SetBackground(dynamic_cast<Tab::Prefs*>(prefs)->riderBackground);
-
     width=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
     height=2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
 
@@ -223,7 +197,7 @@ namespace Lum {
 
     Control::Draw(x,y,w,h); /* We must call Draw of our superclass */
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       draw->activated=false;
       draw->selected=false;
       draw->focused=false;
@@ -271,11 +245,11 @@ namespace Lum {
   Tab::Tab()
   : model(new Model::SizeT(0)),mw(0),mh(0),lastDrawn(NULL)
   {
+    SetBackground(OS::display->GetFill(OS::Display::tabBackgroundFillIndex));
+
     SetCanFocus(true);
 
     AttachModel(model);
-
-    SetPrefs(::Lum::prefs);
   }
 
   Tab::~Tab()
@@ -398,13 +372,15 @@ namespace Lum {
       ++iter;
     }
 
-    mh=std::max(mh,dynamic_cast<Prefs*>(prefs)->tabFrame->topBorder);
+    OS::FrameRef tabFrame=OS::display->GetFrame(OS::Display::tabFrameIndex);
+
+    mh=std::max(mh,tabFrame->topBorder);
 
     ow+=2*OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent);
     oh+=2*OS::display->GetSpaceVertical(OS::Display::spaceGroupIndent);
 
-    height=mh+oh+dynamic_cast<Prefs*>(prefs)->tabFrame->minHeight;
-    width=std::max(ow+dynamic_cast<Prefs*>(prefs)->tabFrame->minWidth,
+    height=mh+oh+tabFrame->minHeight;
+    width=std::max(ow+tabFrame->minWidth,
                    list.size()*mw+
                    OS::display->GetTheme()->GetFirstTabOffset()+
                    OS::display->GetTheme()->GetLastTabOffset());
@@ -436,21 +412,23 @@ namespace Lum {
     size_t  width,height;
     size_t  pos;
 
-    xPos=x+dynamic_cast<Prefs*>(prefs)->tabFrame->leftBorder;
-    yPos=y+mh+dynamic_cast<Prefs*>(prefs)->tabFrame->topBorder;
-    width=this->width-dynamic_cast<Prefs*>(prefs)->tabFrame->minWidth;
-    height=this->height-mh-dynamic_cast<Prefs*>(prefs)->tabFrame->minHeight;
+    OS::FrameRef tabFrame=OS::display->GetFrame(OS::Display::tabFrameIndex);
+
+    xPos=x+tabFrame->leftBorder;
+    yPos=y+mh+tabFrame->topBorder;
+    width=this->width-tabFrame->minWidth;
+    height=this->height-mh-tabFrame->minHeight;
 
     pos=x+OS::display->GetTheme()->GetFirstTabOffset();
     for (std::list<Entry>::iterator iter=list.begin(); iter!=list.end(); ++iter) {
       // Position rider relative to last rider
       iter->rider->MoveResize(pos,y,mw,mh);
-      //iter->rider->Move(pos,y);
       pos+=mw;
 
       // Center object in object area
       iter->object->Resize(width-2*OS::display->GetSpaceHorizontal(OS::Display::spaceGroupIndent),
                            height-2*OS::display->GetSpaceVertical(OS::Display::spaceGroupIndent));
+
       iter->object->Move(xPos+(width-iter->object->GetOWidth()) / 2,
                          yPos+(height-iter->object->GetOHeight()) / 2);
     }
@@ -462,29 +440,28 @@ namespace Lum {
   {
     Control::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
     /* --- */
 
     OS::DrawInfo *draw=GetDrawInfo();
+    OS::FrameRef tabFrame=OS::display->GetFrame(OS::Display::tabFrameIndex);
 
     lastDrawn=GetObject();
 
     draw->PushClipBegin(x,y,w,h);
-
     // Object
     draw->SubClipRegion(lastDrawn->GetOX(),lastDrawn->GetOY(),
                         lastDrawn->GetOWidth(),lastDrawn->GetOHeight());
-
     draw->PushClipEnd();
 
     // Fill background of object with tab control background color
-    DrawBackground(this->x+dynamic_cast<Prefs*>(prefs)->tabFrame->leftBorder,
-                   this->y+mh+dynamic_cast<Prefs*>(prefs)->tabFrame->topBorder,
-                   this->width-dynamic_cast<Prefs*>(prefs)->tabFrame->minWidth,
-                   this->height-mh-dynamic_cast<Prefs*>(prefs)->tabFrame->minHeight);
+    DrawBackground(this->x+tabFrame->leftBorder,
+                   this->y+mh+tabFrame->topBorder,
+                   this->width-tabFrame->minWidth,
+                   this->height-mh-tabFrame->minHeight);
 
     draw->PopClip();
 
@@ -493,6 +470,7 @@ namespace Lum {
       iter->rider->Draw(x,y,w,h);
     }
 
+    // Area before the first tab rider
     if (OS::display->GetTheme()->GetFirstTabOffset()>0) {
       DrawParentBackground(this->x,
                            this->y,
@@ -508,25 +486,25 @@ namespace Lum {
                            this->mh);
     }
 
-    if (dynamic_cast<Prefs*>(prefs)->tabFrame->alpha) {
+    if (tabFrame->alpha) {
       draw->PushClipBegin(this->x,this->y+mh,this->width,this->height-mh);
-      draw->SubClipRegion(this->x+dynamic_cast<Prefs*>(prefs)->tabFrame->leftBorder,
-                          this->y+mh+dynamic_cast<Prefs*>(prefs)->tabFrame->topBorder,
-                          this->width-dynamic_cast<Prefs*>(prefs)->tabFrame->minWidth,
-                          this->height-mh-dynamic_cast<Prefs*>(prefs)->tabFrame->minHeight);
+      draw->SubClipRegion(this->x+tabFrame->leftBorder,
+                          this->y+mh+tabFrame->topBorder,
+                          this->width-tabFrame->minWidth,
+                          this->height-mh-tabFrame->minHeight);
       draw->PushClipEnd();
       DrawParentBackground(this->x,this->y+mh,this->width,this->height-mh);
       draw->PopClip();
     }
-    // Draw frame around object area
-    dynamic_cast<Prefs*>(prefs)->tabFrame->SetGap(OS::display->GetTheme()->GetFirstTabOffset()+
-                                                  model->Get()*mw,mw,h);
 
-   dynamic_cast<Prefs*>(prefs)->tabFrame->Draw(draw,
-                                                this->x,
-                                                this->y+mh,
-                                                this->width,
-                                                this->height-mh);
+    // Draw frame around object area
+    tabFrame->SetGap(OS::display->GetTheme()->GetFirstTabOffset()+model->Get()*mw,mw,0);
+
+    tabFrame->Draw(draw,
+                   this->x,
+                   this->y+mh,
+                   this->width,
+                   this->height-mh);
 
     // Draw currently visible object
     lastDrawn->Draw(x,y,w,h);
@@ -560,7 +538,7 @@ namespace Lum {
           This is a little trick:
           We must hide the old object, but we do not want it to clean up the
           covered area, since it will be overwritten by the new object anyway.
-          So we create a clipping region that completely covers the top be drawn
+          So we create a clipping region that completely covers the to be drawn
           area :-)
         */
         draw->PushClipBegin(lastDrawn->GetOX(),lastDrawn->GetOY(),
