@@ -21,36 +21,26 @@
 
 namespace Lum {
 
-  static Table::Prefs *prefs=new Table::Prefs();
-
-  Table::Prefs::Prefs()
-  : Group::Prefs(L"Table")
-  {
-    // no code
-  }
-
-  void Table::Prefs::Initialize()
-  {
-    Group::Prefs::Initialize();
-
-    frame=OS::display->GetFrame(OS::Display::scrolledFrameIndex);
-  }
-
   Table::Table()
   : object(NULL),hScroller(NULL),vScroller(NULL),
     hVisible(false),vVisible(false),
     table(new TableView()),
-    header(NULL),headerModel(new Model::HeaderImpl()),showHeader(false)
+    header(NULL),headerModel(new Model::HeaderImpl()),showHeader(false),
+    refreshAction(new Model::Action())
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::scrolledBackgroundFillIndex));
 
     SetCanFocus(true);
 
     headerModel->AddColumn(L"",Base::Size::modePixel,32000,true);
+
+    AttachModel(refreshAction);
   }
 
   Table::~Table()
   {
+    UnattachModel(refreshAction);
+
     UnattachModel(table->GetHAdjustment());
     UnattachModel(table->GetVAdjustment());
 
@@ -166,7 +156,7 @@ namespace Lum {
       object=new VPanel();
       object->SetParent(this);
       object->SetFlex(true,true);
-      object->SetFrame(OS::display->GetFrame(OS::Display::listboxFrameIndex));
+      object->SetBackground(OS::display->GetFill(OS::Display::listboxBackgroundFillIndex));
 
       if (showHeader && header!=NULL) {
         dynamic_cast<VPanel*>(object)->Add(header);
@@ -178,16 +168,14 @@ namespace Lum {
     AttachModel(table->GetHAdjustment());
     AttachModel(table->GetVAdjustment());
 
-    vScroller=new Scroller();
+    vScroller=new Scroller(true);
     vScroller->SetParent(this);
-    vScroller->Set(true);
     vScroller->SetFlex(false,true);
     vScroller->SetModel(table->GetVAdjustment());
     vScroller->CalcSize();
 
-    hScroller=new Scroller();
+    hScroller=new Scroller(false);
     hScroller->SetParent(this);
-    hScroller->Set(false);
     hScroller->SetFlex(true,false);
     hScroller->SetModel(table->GetHAdjustment());
     hScroller->CalcSize();
@@ -216,6 +204,23 @@ namespace Lum {
 
   void Table::Layout()
   {
+    if (hVisible && table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal()) {
+      hScroller->Hide();
+      hVisible=false;
+    }
+    else if (!hVisible && table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) {
+      hVisible=true;
+    }
+
+    if (vVisible && table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal()) {
+      vScroller->Hide();
+      vVisible=false;
+    }
+    else if (!vVisible && table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal()) {
+      vVisible=true;
+      SetRelayout();
+    }
+
     table->CalculateDimension();
 
     size_t tWidth,tHeight;
@@ -262,41 +267,26 @@ namespace Lum {
   {
     if (table!=NULL) {
       if (model==table->GetHAdjustment() && table->GetHAdjustment()->IsValid()) {
-        if (hVisible && table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal()) {
-          hScroller->Hide();
-          hVisible=false;
-          SetRelayout();
-          if (visible) {
-            Draw(oX,oY,oWidth,oHeight);
-          }
-        }
-        else if (!hVisible && table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) {
-          hVisible=true;
-          SetRelayout();
-          if (visible) {
-            Draw(oX,oY,oWidth,oHeight);
-          }
+        if (visible) {
+          OS::display->QueueActionForEventLoop(refreshAction);
         }
         return;
       }
       else if (model==table->GetVAdjustment()  && table->GetVAdjustment()->IsValid()) {
-        if (vVisible && table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal()) {
-          vScroller->Hide();
-          vVisible=false;
-          SetRelayout();
-          if (visible) {
-            Draw(oX,oY,oWidth,oHeight);
-          }
-        }
-        else if (!vVisible && table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal()) {
-          vVisible=true;
-          SetRelayout();
-          if (visible) {
-            Draw(oX,oY,oWidth,oHeight);
-          }
+        if (visible) {
+          OS::display->QueueActionForEventLoop(refreshAction);
         }
         return;
       }
+      else if (model==refreshAction && refreshAction->IsFinished()) {
+        if ((hVisible && table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal()) ||
+            (!hVisible && table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) ||
+            (vVisible && table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal()) ||
+            (!vVisible && table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal())) {
+          SetRelayout();
+          Redraw();
+        }
+      }
     }
 
     Group::Resync(model,msg);
