@@ -31,24 +31,7 @@ namespace Lum {
 
 #define STEP 10
 
-  static TableView::Prefs *prefs(new TableView::Prefs);
-  static ControllerRef    controller(new TableView::Controller);
-
-  TableView::Prefs::Prefs()
-  : Object::Prefs(L"TableView")
-  {
-    // no code
-  }
-
-  void TableView::Prefs::Initialize()
-  {
-    Scrollable::Prefs::Initialize();
-
-    background=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
-    background2=OS::display->GetFill(OS::Display::tableBackground2FillIndex);
-
-    focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
-  }
+  static ControllerRef controller(new TableView::Controller);
 
   TableView::FormatProvider::~FormatProvider()
   {
@@ -97,10 +80,11 @@ namespace Lum {
     formatProvider(new FormatProvider()),
     font(OS::display->GetFont())
   {
+    SetBackground(OS::display->GetFill(OS::Display::tableBackgroundFillIndex));
+
     SetCanFocus(true);
     RequestFocus();
 
-    SetPrefs(::Lum::prefs);
     SetController(::Lum::controller);
 
     AttachModel(updateScrollerAction);
@@ -523,7 +507,7 @@ namespace Lum {
     alignment=formatProvider->GetAlignment(x,y);
 
     if (selected) {
-      back=dynamic_cast<Prefs*>(prefs)->background;
+      back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
       draw->PushForeground(OS::Display::fillTextColor);
       draw->selected=true;
     }
@@ -599,8 +583,10 @@ namespace Lum {
     }
 
     if (selected && !selection->IsLineSelected(y) && HasFocus()) {
+      OS::FrameRef focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
+
       /* Draw a frame arond one cell */
-      dynamic_cast<Prefs*>(prefs)->focus->Draw(draw,xPos,yPos,width,height);
+      focus->Draw(draw,xPos,yPos,width,height);
     }
 
     if (cliped) {
@@ -627,7 +613,7 @@ namespace Lum {
     if (selection.Valid() && selection->IsLineSelected(line)) {
       OS::Fill* back;
 
-      back=dynamic_cast<Prefs*>(prefs)->background;
+      back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
 
       drawBackground=false;
 
@@ -651,14 +637,14 @@ namespace Lum {
       OS::Fill* back;
 
       if (selection.Valid() && selection->IsLineSelected(line)) {
-        back=dynamic_cast<Prefs*>(prefs)->background;
+        back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
         draw->selected=true;
       }
       else if (line%2!=0) {
-        back=dynamic_cast<Prefs*>(prefs)->background;
+        back=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
       }
       else {
-        back=dynamic_cast<Prefs*>(prefs)->background2;
+        back=OS::display->GetFill(OS::Display::tableBackground2FillIndex);
       }
 
       back->Draw(draw,
@@ -671,12 +657,14 @@ namespace Lum {
     }
 
     if (selection.Valid() && selection->IsLineSelected(line) && HasFocus()) {
+      OS::FrameRef focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
+
       /* Draw a frame arond whole line */
       if (header->GetColumns()==1) {
-        dynamic_cast<Prefs*>(prefs)->focus->Draw(draw,this->x,y,this->width,rowHeight);
+        focus->Draw(draw,this->x,y,this->width,rowHeight);
       }
       else {
-        dynamic_cast<Prefs*>(prefs)->focus->Draw(draw,this->x-hAdjustment->GetTop()+1,y,tableWidth,rowHeight);
+        focus->Draw(draw,this->x-hAdjustment->GetTop()+1,y,tableWidth,rowHeight);
       }
     }
   }
@@ -773,10 +761,9 @@ namespace Lum {
         w+=dynamic_cast<Table*>(GetParent()->GetParent())->GetVerticalScrollerWidth();
       }
 
-      //if (width>this->width) {
-      ResizeWidth(w+frame->leftBorder+frame->rightBorder);
+      width=w;
+      minWidth=w;
       tableWidth=w;
-      //}
     }
     else {
       RecalcTableWidth();
@@ -819,6 +806,12 @@ namespace Lum {
 
       scrolling=(currentPos!=vAdjustment->GetTop());
 
+      if (OS::display->GetType()==OS::Display::typeTextual) {
+        currentPos=vAdjustment->GetTop();
+        DrawFull(draw);
+        return;
+      }
+
       if (scrolling && scrollRefresh) {
         size_t recentPos=currentPos;
         size_t diff;
@@ -1258,10 +1251,14 @@ namespace Lum {
     }
     else { // unknown/empty message
       if (model==this->model) {
-        if (selection.Valid()) {
+        if (selection.Valid() && selection->HasSelection()) {
           selection->OnClear();
         }
-        currentPos=vAdjustment->GetTop(); // We don't want to scroll on a complete refresh...
+
+        scrollRefresh=false;
+        currentPos=1; // We don't want to scroll on a complete refresh...
+        vAdjustment->SetTop(1);
+        scrollRefresh=false;
         Redraw();
       }
       else if (model==vAdjustment->GetTopModel()) {
