@@ -21,21 +21,6 @@
 
 namespace Lum {
 
-  static Text::Prefs* prefs(new Text::Prefs);
-
-  Text::Prefs::Prefs()
-  : Object::Prefs(L"Text")
-  {
-    // no code
-  }
-
-  void Text::Prefs::Initialize()
-  {
-    Object::Prefs::Initialize();
-
-    focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
-  }
-
   Text::Part::Part(const std::wstring& text,
                    unsigned long style,
                    OS::Font *font)
@@ -166,8 +151,6 @@ namespace Lum {
     defaultStyle(OS::Font::normal),
     defaultFont(OS::display->GetFont())
   {
-    SetPrefs(::Lum::prefs);
-
     SetText(text,style,alignment,font);
   }
 
@@ -395,7 +378,7 @@ namespace Lum {
   {
     Object::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
@@ -494,11 +477,6 @@ namespace Lum {
       ++line;
     }
 
-    /*
-    if ((draw->focused || DisplayFocus()) && (OS::display->GetType()!=OS::Display::typeTextual)) {
-      dynamic_cast<Prefs*>(prefs)->focus->Draw(draw,this->x,this->y,width,height);
-    }*/
-
     draw->PopClip();
     draw->PopForeground();
   }
