@@ -25,25 +25,12 @@
 
 namespace Lum {
 
-  static TextValue::Prefs *prefs=new TextValue::Prefs(L"TextValue");
-
-  TextValue::Prefs::Prefs(const std::wstring& name)
-  : Control::Prefs(name)
-  {
-    // no code
-  }
-
-  void TextValue::Prefs::Initialize()
-  {
-    Control::Prefs::Initialize();
-  }
-
   TextValue::TextValue()
   : font(OS::display->GetFont()),
     alignment(left),
     style(OS::Font::normal)
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 
   TextValue::~TextValue()
@@ -58,7 +45,7 @@ namespace Lum {
 
   size_t TextValue::GetBaseline() const
   {
-    return frame->topBorder+(height-font->height)/2+font->ascent;
+    return GetTopBorder()+(height-font->height)/2+font->ascent;
   }
 
   bool TextValue::SetModel(Base::Model* model)
