@@ -29,25 +29,10 @@
 
 namespace Lum {
 
-  static Time::Prefs* prefs=new Time::Prefs(L"Time");
-
-  Time::Prefs::Prefs(const std::wstring& name)
-    : ControlComponent::Prefs(name)
-  {
-    // no code
-  }
-
-  void Time::Prefs::Initialize()
-  {
-    ControlComponent::Prefs::Initialize();
-  }
-
   Time::Time()
   : format(Base::timeFormatHM),
     hour(new Model::Int()),minute(new Model::Int()),second(new Model::Int())
   {
-    SetPrefs(Lum::prefs);
-
     hour->SetRange(0,23);
     minute->SetRange(0,59);
     second->SetRange(0,59);
