@@ -23,29 +23,11 @@
 
 namespace Lum {
 
-  static Tree::Prefs *prefs=new Tree::Prefs();
-
-  Tree::Prefs::Prefs()
-  : Scrollable::Prefs(L"Tree")
-  {
-    // no code
-  }
-
-  void Tree::Prefs::Initialize()
-  {
-    Scrollable::Prefs::Initialize();
-
-    frame=OS::display->GetFrame(OS::Display::listboxFrameIndex);
-    background=OS::display->GetFill(OS::Display::tableBackgroundFillIndex);
-    focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
-    cross=OS::display->GetImage(OS::Display::treeExpanderImageIndex);
-  }
-
   Tree::Tree()
   : font(OS::display->GetFont()),
     selected(NULL),colHeight(0)
   {
-    SetPrefs(Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::listboxBackgroundFillIndex));
 
     SetCanFocus(true);
     RequestFocus();
@@ -279,7 +261,7 @@ namespace Lum {
     else {
       OS::FontExtent extent;
       int            x;
-      OS::ImageRef   cross=dynamic_cast<Prefs*>(prefs)->cross;
+      OS::ImageRef   cross=OS::display->GetImage(OS::Display::treeExpanderImageIndex);
 
       font->StringExtent(item->GetText(),extent);
       x=this->x+offset*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
@@ -308,10 +290,12 @@ namespace Lum {
 
       if (item==selected) {
         if (HasFocus()) {
-          dynamic_cast<Prefs*>(prefs)->focus->Draw(draw,
-                                                   x+colHeight+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
-                                                   this->y+y+(colHeight-font->height)/2,
-                                                   extent.width,font->height);
+          OS::FrameRef focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
+
+          focus->Draw(draw,
+                      x+colHeight+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
+                      this->y+y+(colHeight-font->height)/2,
+                      extent.width,font->height);
         }
         draw->PushForeground(OS::Display::fillTextColor);
       }
@@ -331,7 +315,7 @@ namespace Lum {
   {
     OS::DrawInfo *draw=GetDrawInfo();
 
-    DrawBackground(x,y,width,height);
+    DrawBackground(oX,oY,oWidth,oHeight);
 
     if (model.Valid() && model->GetTop()!=NULL) {
       size_t            offset;
@@ -379,7 +363,7 @@ namespace Lum {
   {
     Scrollable::Draw(x,y,w,h);
 
-    if (!Intersect(x,y,w,h)) {
+    if (!OIntersect(x,y,w,h)) {
       return;
     }
 
