@@ -23,30 +23,20 @@
 
 namespace Lum {
 
-  static View::Prefs *prefs=new View::Prefs(L"View");
-
-  View::Prefs::Prefs(const std::wstring& name)
-    : Group::Prefs(name)
-  {
-    // no code
-  }
-
-  void View::Prefs::Initialize()
-  {
-    Group::Prefs::Initialize();
-
-    frame=OS::display->GetFrame(OS::Display::scrolledFrameIndex);
-  }
-
   View::View()
   : object(NULL),hScroller(NULL),vScroller(NULL),
-    hVisible(false),vVisible(false)
+    hVisible(false),vVisible(false),
+    refreshAction(new Model::Action())
   {
-    SetPrefs(::Lum::prefs);
+    SetBackground(OS::display->GetFill(OS::Display::scrolledBackgroundFillIndex));
+
+    AttachModel(refreshAction);
   }
 
   View::~View()
   {
+    UnattachModel(refreshAction);
+
     delete hScroller;
     delete vScroller;
     delete object;
@@ -107,15 +97,13 @@ namespace Lum {
   {
     assert(object!=NULL);
 
-    vScroller=new Scroller();
+    vScroller=new Scroller(true);
     vScroller->SetParent(this);
-    vScroller->Set(true);
     vScroller->SetFlex(false,true);
     vScroller->SetModel(object->GetVAdjustment());
 
-    hScroller=new Scroller();
+    hScroller=new Scroller(false);
     hScroller->SetParent(this);
-    hScroller->Set(false);
     hScroller->SetFlex(true,false);
     hScroller->SetModel(object->GetHAdjustment());
 
@@ -150,6 +138,21 @@ namespace Lum {
 
   void View::Layout()
   {
+    if (hVisible && object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal()) {
+      hScroller->Hide();
+      hVisible=false;
+    }
+    else if (!hVisible && object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) {
+      hVisible=true;
+    }
+    if (vVisible && object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal()) {
+      vScroller->Hide();
+      vVisible=false;
+    }
+    else if (!vVisible && object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal()) {
+      vVisible=true;
+    }
+
     object->CalculateDimension();
 
     size_t tWidth,tHeight;
@@ -186,36 +189,23 @@ namespace Lum {
   {
     if (object!=NULL) {
       if (model==object->GetHAdjustment()) {
-        if (hVisible && object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal()) {
-          hScroller->Hide();
-          hVisible=false;
-          SetRelayout();
-          //Redraw();
-          Draw(oX,oY,oWidth,oHeight);
+        if (visible) {
+          OS::display->QueueActionForEventLoop(refreshAction);
         }
-        else if (!hVisible && object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) {
-          hVisible=true;
-          SetRelayout();
-          //Redraw();
-          Draw(oX,oY,oWidth,oHeight);
-        }
-        return;
       }
       else if (model==object->GetVAdjustment()) {
-        if (vVisible && object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal()) {
-          vScroller->Hide();
-          vVisible=false;
-          SetRelayout();
-          //Redraw();
-          Draw(oX,oY,oWidth,oHeight);
+        if (visible) {
+          OS::display->QueueActionForEventLoop(refreshAction);
         }
-        else if (!vVisible && object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal()) {
-          vVisible=true;
+      }
+      else if (model==refreshAction && refreshAction->IsFinished()) {
+        if ((hVisible && object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal()) ||
+            (!hVisible && object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) ||
+            (vVisible && object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal()) ||
+            (!vVisible && object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal())) {
           SetRelayout();
-          //Redraw();
-          Draw(oX,oY,oWidth,oHeight);
+          Redraw();
         }
-        return;
       }
     }
 
